@@ -72,6 +72,12 @@
 #pragma warning(disable: 4505)
 #endif
 
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION >= 2
+#define USE_GTK_CLIPBOARD
+#endif
+
+extern char *UTF8FromLatin1(const char *s, int &len);
+
 class ScintillaGTK : public ScintillaBase {
 	_ScintillaObject *sci;
 	Window wText;
@@ -83,7 +89,7 @@ class ScintillaGTK : public ScintillaBase {
 	int scrollBarHeight;
 
 	// Because clipboard access is asynchronous, copyText is created by Copy
-#if GTK_MAJOR_VERSION == 1
+#ifndef USE_GTK_CLIPBOARD
 	SelectionText copyText;
 #endif
 
@@ -137,6 +143,8 @@ private:
 	virtual void Finalise();
 	virtual void DisplayCursor(Window::Cursor c);
 	virtual void StartDrag();
+	int TargetAsUTF8(char *text);
+	int EncodedFromUTF8(char *utf8, char *encoded);
 public: 	// Public for scintilla_send_message
 	virtual sptr_t WndProc(unsigned int iMessage, uptr_t wParam, sptr_t lParam);
 private:
@@ -172,7 +180,7 @@ private:
 	void ReceivedSelection(GtkSelectionData *selection_data);
 	void ReceivedDrop(GtkSelectionData *selection_data);
 	static void GetSelection(GtkSelectionData *selection_data, guint info, SelectionText *selected);
-#if GTK_MAJOR_VERSION >= 2
+#ifdef USE_GTK_CLIPBOARD
 	static void ClipboardGetSelection(GtkClipboard* clip, GtkSelectionData *selection_data, guint info, void *data);
 	static void ClipboardClearSelection(GtkClipboard* clip, void *data);
 #endif
@@ -422,10 +430,6 @@ void ScintillaGTK::RealizeThis(GtkWidget *widget) {
 	wPreeditDraw = gtk_drawing_area_new();
 	gtk_signal_connect(GTK_OBJECT(PWidget(wPreeditDraw)), "expose_event",
 			   GtkSignalFunc(ExposePreedit), this);
-	gtk_signal_connect_after(GTK_OBJECT(PWidget(wText)), "style_set",
-				 GtkSignalFunc(ScintillaGTK::StyleSetText), NULL);
-	gtk_signal_connect_after(GTK_OBJECT(PWidget(wText)), "realize",
-				 GtkSignalFunc(ScintillaGTK::RealizeText), NULL);
 	gtk_container_add(GTK_CONTAINER(PWidget(wPreedit)), PWidget(wPreeditDraw));
 	gtk_widget_realize(PWidget(wPreedit));
 	gtk_widget_realize(PWidget(wPreeditDraw));
@@ -439,6 +443,10 @@ void ScintillaGTK::RealizeThis(GtkWidget *widget) {
 	gtk_im_context_set_client_window(im_context, widget->window);
 #endif
 #endif
+	gtk_signal_connect_after(GTK_OBJECT(PWidget(wText)), "style_set",
+				 GtkSignalFunc(ScintillaGTK::StyleSetText), NULL);
+	gtk_signal_connect_after(GTK_OBJECT(PWidget(wText)), "realize",
+				 GtkSignalFunc(ScintillaGTK::RealizeText), NULL);
 	gtk_widget_realize(PWidget(wText));
 	gtk_widget_realize(PWidget(scrollbarv));
 	gtk_widget_realize(PWidget(scrollbarh));
@@ -471,6 +479,7 @@ void ScintillaGTK::UnRealizeThis(GtkWidget *widget) {
 	gtk_widget_unrealize(PWidget(wPreedit));
 	gtk_widget_unrealize(PWidget(wPreeditDraw));
 	g_object_unref(im_context);
+	im_context = NULL;
 #endif
 #endif
 	if (GTK_WIDGET_CLASS(parentClass)->unrealize)
@@ -577,16 +586,21 @@ gint ScintillaGTK::FocusIn(GtkWidget *widget, GdkEventFocus * /*event*/) {
 	if (sciThis->ic)
 		gdk_im_begin(sciThis->ic, widget->window);
 #else
-	gchar *str;
-	gint cursor_pos;
-	gtk_im_context_get_preedit_string(sciThis->im_context, &str, NULL, &cursor_pos);
-	if (strlen(str) > 0){
-		gtk_widget_show(PWidget(sciThis->wPreedit));
-	} else{
-		gtk_widget_hide(PWidget(sciThis->wPreedit));
+	if (sciThis->im_context != NULL) {
+		gchar *str = NULL;
+		gint cursor_pos;
+
+		gtk_im_context_get_preedit_string(sciThis->im_context, &str, NULL, &cursor_pos);
+		if (PWidget(sciThis->wPreedit) != NULL) {
+			if (strlen(str) > 0) {
+				gtk_widget_show(PWidget(sciThis->wPreedit));
+			} else {
+				gtk_widget_hide(PWidget(sciThis->wPreedit));
+			}
+		}
+		g_free(str);
+		gtk_im_context_focus_in(sciThis->im_context);
 	}
-	g_free(str);
-	gtk_im_context_focus_in(sciThis->im_context);
 #endif
 #endif
 
@@ -603,8 +617,10 @@ gint ScintillaGTK::FocusOut(GtkWidget *widget, GdkEventFocus * /*event*/) {
 #if GTK_MAJOR_VERSION < 2
 	gdk_im_end();
 #else
-	gtk_widget_hide(PWidget(sciThis->wPreedit));
-	gtk_im_context_focus_out(sciThis->im_context);
+	if (PWidget(sciThis->wPreedit) != NULL)
+		gtk_widget_hide(PWidget(sciThis->wPreedit));
+	if (sciThis->im_context != NULL)
+		gtk_im_context_focus_out(sciThis->im_context);
 #endif
 #endif
 
@@ -613,7 +629,7 @@ gint ScintillaGTK::FocusOut(GtkWidget *widget, GdkEventFocus * /*event*/) {
 
 void ScintillaGTK::SizeRequest(GtkWidget *widget, GtkRequisition *requisition) {
 	requisition->width = 600;
-	requisition->height = 2000;
+	requisition->height = gdk_screen_height();
 	ScintillaGTK *sciThis = ScintillaFromWidget(widget);
 	GtkRequisition child_requisition;
 	gtk_widget_size_request(PWidget(sciThis->scrollbarh), &child_requisition);
@@ -700,7 +716,7 @@ void ScintillaGTK::Initialise() {
 	gtk_selection_add_targets(GTK_WIDGET(PWidget(wMain)), GDK_SELECTION_PRIMARY,
 	                          clipboardTargets, nClipboardTargets);
 
-#if GTK_MAJOR_VERSION == 1
+#ifndef USE_GTK_CLIPBOARD
 	gtk_selection_add_targets(GTK_WIDGET(PWidget(wMain)), atomClipboard,
 	                          clipboardTargets, nClipboardTargets);
 #endif
@@ -727,9 +743,10 @@ void ScintillaGTK::DisplayCursor(Window::Cursor c) {
 void ScintillaGTK::StartDrag() {
 	dragWasDropped = false;
 	static const GtkTargetEntry targets[] = {
+	    { "UTF8_STRING", 0, TARGET_UTF8_STRING },
 	    { "STRING", 0, TARGET_STRING },
-	    { "TEXT", 0, TARGET_TEXT },
-	    { "COMPOUND_TEXT", 0, TARGET_COMPOUND_TEXT },
+	    // { "TEXT", 0, TARGET_TEXT },
+	    // { "COMPOUND_TEXT", 0, TARGET_COMPOUND_TEXT },
 	};
 	static const gint n_targets = sizeof(targets) / sizeof(targets[0]);
 	GtkTargetList *tl = gtk_target_list_new(targets, n_targets);
@@ -740,6 +757,116 @@ void ScintillaGTK::StartDrag() {
 	               reinterpret_cast<GdkEvent *>(&evbtn));
 }
 
+#ifdef USE_CONVERTER
+static char *ConvertText(int *lenResult, char *s, size_t len, const char *charSetDest, const char *charSetSource) {
+	*lenResult = 0;
+	char *destForm = 0;
+	Converter conv(charSetDest, charSetSource);
+	if (conv) {
+		destForm = new char[len*3+1];
+		char *pin = s;
+		size_t inLeft = len;
+		char *pout = destForm;
+		size_t outLeft = len*3+1;
+		size_t conversions = conv.Convert(&pin, &inLeft, &pout, &outLeft);
+		if (conversions == ((size_t)(-1))) {
+fprintf(stderr, "iconv %s->%s failed for %s\n", charSetSource, charSetDest, static_cast<char *>(s));
+			delete []destForm;
+			destForm = 0;
+		} else {
+//fprintf(stderr, "iconv OK %s %d\n", destForm, pout - destForm);
+			*pout = '\0';
+			*lenResult = pout - destForm;
+		}
+	} else {
+fprintf(stderr, "Can not iconv %s %s\n", charSetDest, charSetSource);
+	}
+	if (!destForm) {
+		destForm = new char[1];
+		destForm[0] = '\0';
+		*lenResult = 0;
+	}
+	return destForm;
+}
+#endif
+
+// Returns the target converted to UTF8.
+// Return the length in bytes.
+int ScintillaGTK::TargetAsUTF8(char *text) {
+	int targetLength = targetEnd - targetStart;
+	if (IsUnicodeMode()) {
+		if (text) {
+			pdoc->GetCharRange(text, targetStart, targetLength);
+		}
+	} else {
+		// Need to convert
+#ifdef USE_CONVERTER
+		const char *charSetBuffer = CharacterSetID();
+		if (*charSetBuffer) {
+//~ fprintf(stderr, "AsUTF8 %s %d  %0d-%0d\n", charSetBuffer, targetLength, targetStart, targetEnd);
+			char *s = new char[targetLength];
+			if (s) {
+				pdoc->GetCharRange(s, targetStart, targetLength);
+//~ fprintf(stderr, "    \"%s\"\n", s);
+				if (text) {
+					char *tmputf = ConvertText(&targetLength, s, targetLength, "UTF-8", charSetBuffer);
+					memcpy(text, tmputf, targetLength);
+					delete []tmputf;
+//~ fprintf(stderr, "    \"%s\"\n", text);
+				}
+				delete []s;
+			}
+		} else {
+			if (text) {
+				pdoc->GetCharRange(text, targetStart, targetLength);
+			}
+		}
+#else
+		// Fail
+		return 0;
+#endif
+	}
+//~ fprintf(stderr, "Length = %d bytes\n", targetLength);
+	return targetLength;
+}
+
+// Translates a nul terminated UTF8 string into the document encoding.
+// Return the length of the result in bytes.
+int ScintillaGTK::EncodedFromUTF8(char *utf8, char *encoded) {
+	int inputLength = (lengthForEncode >= 0) ? lengthForEncode : strlen(utf8);
+	if (IsUnicodeMode()) {
+		if (encoded) {
+			memcpy(encoded, utf8, inputLength);
+		}
+		return inputLength;
+	} else {
+		// Need to convert
+#ifdef USE_CONVERTER
+		const char *charSetBuffer = CharacterSetID();
+		if (*charSetBuffer) {
+//~ fprintf(stderr, "Encode %s %d\n", charSetBuffer, inputLength);
+			int outLength = 0;
+			char *tmpEncoded = ConvertText(&outLength, utf8, inputLength, charSetBuffer, "UTF-8");
+			if (tmpEncoded) {
+//~ fprintf(stderr, "    \"%s\"\n", tmpEncoded);
+				if (encoded) {
+					memcpy(encoded, tmpEncoded, outLength);
+				}
+				delete []tmpEncoded;
+			}
+			return outLength;
+		} else {
+			if (encoded) {
+				memcpy(encoded, utf8, inputLength);
+			}
+			return inputLength;
+		}
+#endif
+	}
+	// Fail
+	return 0;
+}
+
 sptr_t ScintillaGTK::WndProc(unsigned int iMessage, uptr_t wParam, sptr_t lParam) {
 	switch (iMessage) {
 
@@ -755,9 +882,15 @@ sptr_t ScintillaGTK::WndProc(unsigned int iMessage, uptr_t wParam, sptr_t lParam
 
 #ifdef SCI_LEXER
 	case SCI_LOADLEXERLIBRARY:
-		LexerManager::GetInstance()->Load(reinterpret_cast<const char*>( wParam ));
+		LexerManager::GetInstance()->Load(reinterpret_cast<const char*>(wParam));
 		break;
 #endif
+	case SCI_TARGETASUTF8:
+		return TargetAsUTF8(reinterpret_cast<char*>(lParam));
+
+	case SCI_ENCODEDFROMUTF8:
+		return EncodedFromUTF8(reinterpret_cast<char*>(wParam),
+			reinterpret_cast<char*>(lParam));
 
 	default:
 		return ScintillaBase::WndProc(iMessage, wParam, lParam);
@@ -921,14 +1054,17 @@ void ScintillaGTK::ScrollText(int linesToMove) {
 	gdk_gc_unref(gc);
 #else
 	gdk_window_scroll(wi->window, 0, -diff);
+	gdk_window_process_updates(wi->window, FALSE);
 #endif
 }
 
 void ScintillaGTK::SetVerticalScrollPos() {
+	DwellEnd(true);
 	gtk_adjustment_set_value(GTK_ADJUSTMENT(adjustmentv), topLine);
 }
 
 void ScintillaGTK::SetHorizontalScrollPos() {
+	DwellEnd(true);
 	gtk_adjustment_set_value(GTK_ADJUSTMENT(adjustmenth), xOffset / 2);
 }
 
@@ -984,7 +1120,7 @@ void ScintillaGTK::NotifyParent(SCNotification scn) {
 }
 
 void ScintillaGTK::NotifyKey(int key, int modifiers) {
-	SCNotification scn;
+	SCNotification scn = {0};
 	scn.nmhdr.code = SCN_KEY;
 	scn.ch = key;
 	scn.modifiers = modifiers;
@@ -993,7 +1129,7 @@ void ScintillaGTK::NotifyKey(int key, int modifiers) {
 }
 
 void ScintillaGTK::NotifyURIDropped(const char *list) {
-	SCNotification scn;
+	SCNotification scn = {0};
 	scn.nmhdr.code = SCN_URIDROPPED;
 	scn.text = list;
 
@@ -1133,8 +1269,8 @@ int ScintillaGTK::KeyDefault(int key, int modifiers) {
 }
 
 void ScintillaGTK::CopyToClipboard(const SelectionText &selectedText) {
-#if GTK_MAJOR_VERSION == 1
-	copyText.Copy(selectedText.s, selectedText.len, selectedText.characterSet);
+#ifndef USE_GTK_CLIPBOARD
+	copyText.Copy(selectedText);
 	gtk_selection_owner_set(GTK_WIDGET(PWidget(wMain)),
 				atomClipboard,
 				GDK_CURRENT_TIME);
@@ -1145,7 +1281,7 @@ void ScintillaGTK::CopyToClipboard(const SelectionText &selectedText) {
 		return;
 
 	SelectionText *clipText = new SelectionText();
-	clipText->Copy(selectedText.s, selectedText.len, selectedText.characterSet);
+	clipText->Copy(selectedText);
 
 	gtk_clipboard_set_with_data(clipBoard, clipboardTargets, nClipboardTargets,
 				    ClipboardGetSelection, ClipboardClearSelection, clipText);
@@ -1155,7 +1291,7 @@ void ScintillaGTK::CopyToClipboard(const SelectionText &selectedText) {
 
 void ScintillaGTK::Copy() {
 	if (currentPos != anchor) {
-#if GTK_MAJOR_VERSION == 1
+#ifndef USE_GTK_CLIPBOARD
 		CopySelectionRange(&copyText);
 		gtk_selection_owner_set(GTK_WIDGET(PWidget(wMain)),
 		                        atomClipboard,
@@ -1201,12 +1337,15 @@ void ScintillaGTK::CreateCallTipWindow(PRectangle rc) {
 		gtk_widget_set_events(PWidget(ct.wDraw),
 			GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK);
 	}
+
 	gtk_drawing_area_size(GTK_DRAWING_AREA(PWidget(ct.wDraw)),
 	                      rc.Width(), rc.Height());
 	ct.wDraw.Show();
 	//ct.wCallTip.Show();
 	//gtk_widget_set_usize(PWidget(ct.wCallTip), rc.Width(), rc.Height());
-	gdk_window_resize(PWidget(ct.wCallTip)->window, rc.Width(), rc.Height());
+
+	if( PWidget(ct.wCallTip)->window != NULL )
+		gdk_window_resize(PWidget(ct.wCallTip)->window, rc.Width(), rc.Height());
 }
 
 void ScintillaGTK::AddToPopUp(const char *label, int cmd, bool enabled) {
@@ -1246,91 +1385,28 @@ void ScintillaGTK::ClaimSelection() {
 		primarySelection = true;
 		gtk_selection_owner_set(GTK_WIDGET(PWidget(wMain)),
 		                        GDK_SELECTION_PRIMARY, GDK_CURRENT_TIME);
-		primary.Set(0, 0, 0);
+		primary.Free();
 	} else if (OwnPrimarySelection()) {
 		primarySelection = true;
 		if (primary.s == NULL)
 			gtk_selection_owner_set(NULL, GDK_SELECTION_PRIMARY, GDK_CURRENT_TIME);
 	} else {
 		primarySelection = false;
-		primary.Set(0, 0, 0);
+		primary.Free();
 	}
 }
 
-#ifdef USE_CONVERTER
-static char *ConvertText(size_t *lenResult, char *s, size_t len, const char *charSetDest, const char *charSetSource) {
-	*lenResult = 0;
-	char *destForm = 0;
-	Converter conv(charSetDest, charSetSource);
-	if (conv) {
-		destForm = new char[len*3+1];
-		char *pin = s;
-		size_t inLeft = len;
-		char *pout = destForm;
-		size_t outLeft = len*3+1;
-		size_t conversions = conv.Convert(&pin, &inLeft, &pout, &outLeft);
-		if (conversions == ((size_t)(-1))) {
-fprintf(stderr, "iconv failed for %s\n", static_cast<char *>(s));
-			delete []destForm;
-			destForm = 0;
-		} else {
-//fprintf(stderr, "iconv OK %s %d\n", destForm, pout - destForm);
-			*pout = '\0';
-			*lenResult = pout - destForm;
-		}
-	} else {
-//fprintf(stderr, "Can not iconv %s %s\n", charSetDest, charSetSource);
-	}
-	if (!destForm) {
-		destForm = new char[1];
-		destForm[0] = '\0';
-		*lenResult = 0;
-	}
-	return destForm;
-}
-#endif
-
-// Convert line endings for a piece of text to a particular mode.
-// Stop at len or when a NUL is found.
-char *ConvertLineEnds(size_t *pLenOut, const char *s, size_t len, int eolMode) {
-	char *dest = new char[2 * len + 1];
-	const char *sptr = s;
-	char *dptr = dest;
-	for (size_t i = 0; (i < len) && (*sptr != '\0'); i++) {
-		if (*sptr == '\n' || *sptr == '\r') {
-			if (eolMode == SC_EOL_CR) {
-				*dptr++ = '\r';
-			} else if (eolMode == SC_EOL_LF) {
-				*dptr++ = '\n';
-			} else { // eolMode == SC_EOL_CRLF
-				*dptr++ = '\r';
-				*dptr++ = '\n';
-			}
-			if ((*sptr == '\r') && (i+1 < len) && (*(sptr+1) == '\n')) {
-				i++;
-				sptr++;
-			}
-			sptr++;
-		} else {
-			*dptr++ = *sptr++;
-		}
-	}
-	*dptr++ = '\0';
-	*pLenOut = (dptr - dest) - 1;
-	return dest;
-}
-
 // Detect rectangular text, convert line ends to current mode, convert from or to UTF-8
 void ScintillaGTK::GetGtkSelectionText(GtkSelectionData *selectionData, SelectionText &selText) {
 	char *data = reinterpret_cast<char *>(selectionData->data);
-	size_t len = selectionData->length;
+	int len = selectionData->length;
 	GdkAtom selectionType = selectionData->type;
 
 	// Return empty string if selection is not a string
 	if ((selectionType != GDK_TARGET_STRING) && (selectionType != atomUTF8)) {
 		char *empty = new char[1];
 		empty[0] = '\0';
-		selText.Set(empty, 0, SC_CP_UTF8);
+		selText.Set(empty, 0, SC_CP_UTF8, 0, false);
 		return;
 	}
 
@@ -1342,48 +1418,34 @@ void ScintillaGTK::GetGtkSelectionText(GtkSelectionData *selectionData, Selectio
 	isRectangular = ((len > 2) && (data[len - 1] == 0 && data[len - 2] == '\n'));
 #endif
 
-#if GTK_MAJOR_VERSION >= 2
 	char *dest;
-	char *utf8 = reinterpret_cast<char*>(gtk_selection_data_get_text(selectionData));
-	if (utf8 != NULL) {
-		dest = ConvertLineEnds(&len, utf8, strlen(utf8), pdoc->eolMode);
-		g_free(utf8);
-	}
-	else {
-		dest = new char[1];
-		dest[0] = '\0';
-		len = 0;
-	}
-	selText.Set(dest, len, SC_CP_UTF8, isRectangular);
-#else
-	char *dest = ConvertLineEnds(&len, data, len, pdoc->eolMode);
-	if (selectionType == GDK_TARGET_STRING)
-		selText.Set(dest, len, pdoc->dbcsCodePage, isRectangular);
-	else
-		selText.Set(dest, len, SC_CP_UTF8, isRectangular);
-#endif
-
-#ifdef USE_CONVERTER
-	// Possible character set conversion
-	const char *charSetBuffer = CharacterSetID();
-	if (*charSetBuffer) {
+	if (selectionType == GDK_TARGET_STRING) {
+		dest = Document::TransformLineEnds(&len, data, len, pdoc->eolMode);
 		if (IsUnicodeMode()) {
-			if (selText.characterSet != SC_CP_UTF8) {
-				// Convert to UTF-8
-//fprintf(stderr, "Convert to UTF-8 from %s\n", charSetBuffer);
-				dest = ConvertText(&len, selText.s, selText.len, "UTF-8", charSetBuffer);
-				selText.Set(dest, len, SC_CP_UTF8, selText.rectangular);
-			}
+			// Unknown encoding so assume in Latin1
+			char *destPrevious = dest;
+			dest = UTF8FromLatin1(dest, len);
+			selText.Set(dest, len, SC_CP_UTF8, 0, selText.rectangular);
+			delete []destPrevious;
 		} else {
-			if (selText.characterSet == SC_CP_UTF8) {
-//fprintf(stderr, "Convert to locale %s\n", charSetBuffer);
+			// Assume buffer is in same encoding as selection
+			selText.Set(dest, len, pdoc->dbcsCodePage,
+				vs.styles[STYLE_DEFAULT].characterSet, isRectangular);
+		}
+	} else {	// UTF-8
+		dest = Document::TransformLineEnds(&len, data, len, pdoc->eolMode);
+		selText.Set(dest, len, SC_CP_UTF8, 0, isRectangular);
+#ifdef USE_CONVERTER
+		const char *charSetBuffer = CharacterSetID();
+		if (!IsUnicodeMode() && *charSetBuffer) {
+//fprintf(stderr, "Convert to locale %s\n", CharacterSetID());
 				// Convert to locale
 				dest = ConvertText(&len, selText.s, selText.len, charSetBuffer, "UTF-8");
-				selText.Set(dest, len, pdoc->dbcsCodePage, selText.rectangular);
-			}
+				selText.Set(dest, len, pdoc->dbcsCodePage,
+					vs.styles[STYLE_DEFAULT].characterSet, selText.rectangular);
 		}
-	}
 #endif
+	}
 }
 
 void ScintillaGTK::ReceivedSelection(GtkSelectionData *selection_data) {
@@ -1399,10 +1461,10 @@ void ScintillaGTK::ReceivedSelection(GtkSelectionData *selection_data) {
 			GetGtkSelectionText(selection_data, selText);
 
 			pdoc->BeginUndoAction();
-			int selStart = SelectionStart();
 			if (selection_data->selection != GDK_SELECTION_PRIMARY) {
 				ClearSelection();
 			}
+			int selStart = SelectionStart();
 
 			if (selText.rectangular) {
 				PasteRectangular(selStart, selText.s, selText.len);
@@ -1437,14 +1499,16 @@ void ScintillaGTK::ReceivedDrop(GtkSelectionData *selection_data) {
 
 void ScintillaGTK::GetSelection(GtkSelectionData *selection_data, guint info, SelectionText *text) {
 #if GTK_MAJOR_VERSION >= 2
-	(void)info;	// Parameter unused on GTK+ 2
 	// Convert text to utf8 if it isn't already
-	if (text->characterSet != SC_CP_UTF8) {
+	SelectionText *converted = 0;
+	if ((text->codePage != SC_CP_UTF8) && (info == TARGET_UTF8_STRING)) {
 		const char *charSet = ::CharacterSetID(text->characterSet);
 		if (*charSet) {
-			size_t new_len;
+			int new_len;
 			char* tmputf = ConvertText(&new_len, text->s, text->len, "UTF-8", charSet);
-			text->Set(tmputf, new_len, SC_CP_UTF8, text->rectangular);
+			converted = new SelectionText();
+			converted->Set(tmputf, new_len, SC_CP_UTF8, 0, text->rectangular);
+			text = converted;
 		}
 	}
 
@@ -1461,7 +1525,14 @@ void ScintillaGTK::GetSelection(GtkSelectionData *selection_data, guint info, Se
 		len++;
 #endif
 
-	gtk_selection_data_set_text(selection_data, text->s, len);
+	if (info == TARGET_UTF8_STRING) {
+		gtk_selection_data_set_text(selection_data, text->s, len);
+	} else {
+		gtk_selection_data_set(selection_data,
+			static_cast<GdkAtom>(GDK_SELECTION_TYPE_STRING),
+			8, reinterpret_cast<unsigned char *>(text->s), len);
+	}
+	delete converted;
 
 #else /* Gtk 1 */
 	char *selBuffer = text->s;
@@ -1471,26 +1542,26 @@ void ScintillaGTK::GetSelection(GtkSelectionData *selection_data, guint info, Se
 	// Many native win32 programs require \n line endings,
 	 // so make a copy of the clip text now with newlines converted
 
-	size_t new_len;
-	char *tmpstr = ConvertLineEnds(&new_len, selBuffer, text->len, SC_EOL_LF);
+	int new_len;
+	char *tmpstr = Document::TransformLineEnds(&new_len, selBuffer, text->len, SC_EOL_LF);
 	selBuffer = tmpstr;
 #endif
 	char *tmputf = 0;
 	if ((info == TARGET_UTF8_STRING) || (info == TARGET_STRING)) {
-		size_t len = strlen(selBuffer);
+		int len = strlen(selBuffer);
 #ifdef USE_CONVERTER
 		// Possible character set conversion
 		const char *charSetBuffer = ::CharacterSetID(text->characterSet);
 		if (info == TARGET_UTF8_STRING) {
 			//fprintf(stderr, "Copy to clipboard as UTF-8\n");
-			if (text->characterSet != SC_CP_UTF8) {
+			if (text->codePage != SC_CP_UTF8) {
 				// Convert to UTF-8
 	//fprintf(stderr, "Convert to UTF-8 from %s\n", charSetBuffer);
 				tmputf = ConvertText(&len, selBuffer, len, "UTF-8", charSetBuffer);
 				selBuffer = tmputf;
 			}
 		} else if (info == TARGET_STRING) {
-			if (text->characterSet == SC_CP_UTF8) {
+			if (text->codePage == SC_CP_UTF8) {
 	//fprintf(stderr, "Convert to locale %s\n", charSetBuffer);
 				// Convert to locale
 				tmputf = ConvertText(&len, selBuffer, len, charSetBuffer, "UTF-8");
@@ -1534,7 +1605,7 @@ void ScintillaGTK::GetSelection(GtkSelectionData *selection_data, guint info, Se
 #endif /* Gtk >= 2 */
 }
 
-#if GTK_MAJOR_VERSION >= 2
+#ifdef USE_GTK_CLIPBOARD
 void ScintillaGTK::ClipboardGetSelection(GtkClipboard *, GtkSelectionData *selection_data, guint info, void *data) {
 	GetSelection(selection_data, info, static_cast<SelectionText*>(data));
 }
@@ -1550,7 +1621,7 @@ void ScintillaGTK::UnclaimSelection(GdkEventSelection *selection_event) {
 	if (selection_event->selection == GDK_SELECTION_PRIMARY) {
 		//Platform::DebugPrintf("UnclaimPrimarySelection\n");
 		if (!OwnPrimarySelection()) {
-			primary.Set(0, 0, 0);
+			primary.Free();
 			primarySelection = false;
 			FullPaint();
 		}
@@ -1647,16 +1718,19 @@ gint ScintillaGTK::PressThis(GdkEventButton *event) {
 
 	gtk_widget_grab_focus(PWidget(wMain));
 	if (event->button == 1) {
-		//ButtonDown(pt, event->time,
-		//	event->state & GDK_SHIFT_MASK,
-		//	event->state & GDK_CONTROL_MASK,
-		//	event->state & GDK_MOD1_MASK);
-		// Instead of sending literal modifiers use control instead of alt
-		// This is because all the window managers seem to grab alt + click for moving
+		// On X, instead of sending literal modifiers use control instead of alt
+		// This is because most X window managers grab alt + click for moving
+#if !PLAT_GTK_WIN32
 		ButtonDown(pt, event->time,
-		                    (event->state & GDK_SHIFT_MASK) != 0,
-		                    (event->state & GDK_CONTROL_MASK) != 0,
-		                    (event->state & GDK_CONTROL_MASK) != 0);
+				    (event->state & GDK_SHIFT_MASK) != 0,
+				    (event->state & GDK_CONTROL_MASK) != 0,
+				    (event->state & GDK_CONTROL_MASK) != 0);
+#else
+		ButtonDown(pt, event->time,
+				    (event->state & GDK_SHIFT_MASK) != 0,
+				    (event->state & GDK_CONTROL_MASK) != 0,
+				    (event->state & GDK_MOD1_MASK) != 0);
+#endif
 	} else if (event->button == 2) {
 		// Grab the primary selection if it exists
 		Position pos = PositionFromLocation(pt);
@@ -2187,7 +2261,7 @@ void ScintillaGTK::SelectionGet(GtkWidget *widget,
 		}
 		sciThis->GetSelection(selection_data, info, &sciThis->primary);
 	}
-#if GTK_MAJOR_VERSION == 1 /* Gtk 2+ uses GtkClipboard for non-primary selections. */
+#ifndef USE_GTK_CLIPBOARD
 	else {
 		sciThis->GetSelection(selection_data, info, &sciThis->copyText);
 	}
@@ -2344,8 +2418,8 @@ static void scintilla_init(ScintillaObject *sci);
 extern void Platform_Initialise();
 extern void Platform_Finalise();
 
-guint scintilla_get_type() {
-	static guint scintilla_type = 0;
+GtkType scintilla_get_type() {
+	static GtkType scintilla_type = 0;
 
 	if (!scintilla_type) {
 		Platform_Initialise();
