@@ -96,17 +96,20 @@ void MarkerHandleSet::RemoveHandle(int handle) {
 	}
 }
 
-void MarkerHandleSet::RemoveNumber(int markerNum) {
+bool MarkerHandleSet::RemoveNumber(int markerNum) {
+	bool performedDeletion = false;
 	MarkerHandleNumber **pmhn = &root;
 	while (*pmhn) {
 		MarkerHandleNumber *mhn = *pmhn;
 		if (mhn->number == markerNum) {
 			*pmhn = mhn->next;
 			delete mhn;
+			performedDeletion = true;
 		} else {
 			pmhn = &((*pmhn)->next);
 		}
 	}
+	return performedDeletion;
 }
 
 void MarkerHandleSet::CombineWith(MarkerHandleSet *other) {
@@ -251,13 +254,14 @@ void LineVector::Remove(int pos) {
 		linesData[i] = linesData[i + 1];
 	}
 	if (levels) {
-		// Level information merges back onto previous line
-		int posAbove = pos - 1;
-		if (posAbove < 0)
-			posAbove = 0;
-		for (int j = posAbove; j < lines; j++) {
+		// Move up following lines but merge header flag from this line
+		// to line before to avoid a temporary disappearence causing expansion.
+		int firstHeader = levels[pos] & SC_FOLDLEVELHEADERFLAG;
+		for (int j = pos; j < lines; j++) {
 			levels[j] = levels[j + 1];
 		}
+		if (pos > 0)
+			levels[pos-1] |= firstHeader;
 	}
 	lines--;
 }
@@ -306,13 +310,18 @@ void LineVector::MergeMarkers(int pos) {
 	}
 }
 
-void LineVector::DeleteMark(int line, int markerNum) {
+void LineVector::DeleteMark(int line, int markerNum, bool all) {
 	if (linesData[line].handleSet) {
 		if (markerNum == -1) {
 			delete linesData[line].handleSet;
 			linesData[line].handleSet = 0;
 		} else {
-			linesData[line].handleSet->RemoveNumber(markerNum);
+			bool performedDeletion = 
+				linesData[line].handleSet->RemoveNumber(markerNum);
+			while (all && performedDeletion) {
+				performedDeletion = 
+					linesData[line].handleSet->RemoveNumber(markerNum);
+			}
 			if (linesData[line].handleSet->Length() == 0) {
 				delete linesData[line].handleSet;
 				linesData[line].handleSet = 0;
@@ -442,6 +451,9 @@ void UndoHistory::AppendAction(actionType at, int position, char *data, int leng
 	//Platform::DebugPrintf("%% %d action %d %d %d\n", at, position, lengthData, currentAction);
 	//Platform::DebugPrintf("^ %d action %d %d\n", actions[currentAction - 1].at,
 	//	actions[currentAction - 1].position, actions[currentAction - 1].lenData);
+	if (currentAction < savePoint) {
+		savePoint = -1;
+	}
 	if (currentAction >= 1) {
 		if (0 == undoSequenceDepth) {
 			// Top level actions may not always be coalesced
@@ -833,7 +845,7 @@ int CellBuffer::AddMark(int line, int markerNum) {
 
 void CellBuffer::DeleteMark(int line, int markerNum) {
 	if ((line >= 0) && (line < lv.lines)) {
-		lv.DeleteMark(line, markerNum);
+		lv.DeleteMark(line, markerNum, false);
 	}
 }
 
@@ -849,7 +861,7 @@ int CellBuffer::GetMark(int line) {
 
 void CellBuffer::DeleteAllMarks(int markerNum) {
 	for (int line = 0; line < lv.lines; line++) {
-		lv.DeleteMark(line, markerNum);
+		lv.DeleteMark(line, markerNum, true);
 	}
 }
 
@@ -1017,7 +1029,7 @@ void CellBuffer::DeleteUndoHistory() {
 }
 
 bool CellBuffer::CanUndo() {
-	return (!readOnly) && (uh.CanUndo());
+	return uh.CanUndo();
 }
 
 int CellBuffer::StartUndo() {
@@ -1045,7 +1057,7 @@ void CellBuffer::PerformUndoStep() {
 }
 
 bool CellBuffer::CanRedo() {
-	return (!readOnly) && (uh.CanRedo());
+	return uh.CanRedo();
 }
 
 int CellBuffer::StartRedo() {
