@@ -3,7 +3,7 @@
  ** Lexer for Cascade Style Sheets
  ** Written by Jakub Vrna
  ** *******************************
- ** Modified by Iago Rubio to cssed
+ ** Modified by Iago Rubio for cssed
  ** Tue Dec 16 13:32:20 2003
  ** *******************************
  **
@@ -478,7 +478,7 @@ ColouriseCssDoc (unsigned int startPos, int length, int initStyle,
 			switch (sc.state)
 			{
 			case SCE_CSS_DIRECTIVE:		
-				if( strcmp(s2,"page") ==0 ){
+				if( strcmp(s2,"page") ==0 || strcmp(s2, "font-face") == 0){
 					sc.ForwardSetState( SCE_CSS_TAG );
 				}
 				break;				
@@ -508,13 +508,14 @@ ColouriseCssDoc (unsigned int startPos, int length, int initStyle,
 				}
 				else if (namedColors.InList (s2))
 				{
-					sc.ChangeState (SCE_CSS_COLOR);
 					if (sc.ch == ' ')
 					{
+						sc.ChangeState (SCE_CSS_COLOR);
 						sc.ForwardSetState	(SCE_CSS_VALUE);
 					}
 					else if (IsCssOperator (sc.ch))
 					{
+						sc.ChangeState (SCE_CSS_COLOR);
 						sc.SetState	(SCE_CSS_OPERATOR);
 						if (sc.ch == ';')
 							sc.ForwardSetState(SCE_CSS_IDENTIFIER);
