@@ -1,4 +1,4 @@
-/*  cssed (c) Iago Rubio 2003, 2004 - A tiny CSS editor.
+/*  cssed (c) Iago Rubio 2003, 2005 - A tiny CSS editor.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -550,10 +550,11 @@ create_color_wizard_dialog (CssedWindow* window)
   gtk_dialog_add_action_widget (GTK_DIALOG (color_wizard_dialog), okbutton, GTK_RESPONSE_OK);
   GTK_WIDGET_SET_FLAGS (okbutton, GTK_CAN_DEFAULT);
 
-
+/*
   g_signal_connect ((gpointer) color_wizard_dialog, "close",
                     G_CALLBACK (on_color_wizard_dialog_close),
                     NULL);
+*/
   g_signal_connect ((gpointer) button_fore, "clicked",
                     G_CALLBACK (on_button_fore_clicked),
                     NULL);
@@ -874,7 +875,7 @@ write_results_to_document(GtkWidget* parent, CssedWindow* window)
 	if(!bfore && !bback && !battach && !bborder_top && 
 	   !bborder_right && !bborder_bottom && !bborder_left && !boutline )
 	{
-		cssed_error_message("Nothing was selected.","No value to add");
+		cssed_error_message("No value to add", "Nothing was selected.");
 		return;		
 	}
 	
