@@ -1,4 +1,4 @@
-/*  cssed (c) Iago Rubio 2003, 2004 - A tiny CSS editor.
+/*  cssed (c) Iago Rubio 2003, 2005 - A tiny CSS editor.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 #  include <config.h>
 #endif
 
+#include <string.h>
 #include <gtk/gtk.h>
 
 #include "cssedwindow.h"
@@ -1198,6 +1199,36 @@ on_apply_font_button_clicked         	(GtkButton       *button,
 		g_free(labelstr);
 	}	
 }
+
+/* browser */
+void
+on_apply_browser_button_clicked         (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	CssedWindow* window;
+	CssedConfig* cfg;
+	GtkWidget* label;
+	GtkWidget* entry;
+	G_CONST_RETURN gchar* command;
+
+	window = CSSED_WINDOW(user_data);
+	cfg = cssed_window_get_config( window );	
+	entry = lookup_widget(GTK_WIDGET(button),"entry_browser");
+	label = lookup_widget(GTK_WIDGET(button), "label_current_browser");
+
+	if( !(cfg && label) ) return;
+
+	command = gtk_entry_get_text(GTK_ENTRY(entry));
+
+	if( strlen(command) < 1 ) {
+		return;
+	}else{
+		if( cfg->browser_command != NULL ) g_free(cfg->browser_command);
+		cfg->browser_command = g_strdup(command);
+		gtk_label_set_text(GTK_LABEL(label), command);
+	}	
+}
+
 /* 
 	called by all buttons to set the window->config fields value and update
 	the pango markup in button's labels to show the current color 
@@ -1215,20 +1246,32 @@ config_dialog_change_style_and_button_markup( GtkButton* button, gint* style)
 	GtkWidget* label;
 	gchar* markup;
 	gchar* colorstr;
-	
+	G_CONST_RETURN gchar* label_text;
+
+	child = gtk_container_get_children (GTK_CONTAINER(button));
+	label = g_list_first( child )->data;
 	colorselection = gtk_color_selection_dialog_new  (_("Select a color for this style") );
-	resp = gtk_dialog_run( GTK_DIALOG(colorselection) );
 	colorsel = GTK_COLOR_SELECTION_DIALOG(colorselection)->colorsel;
+
+	label_text = gtk_label_get_label(GTK_LABEL(label)) ;
+	colorstr = g_strndup (label_text + 18, 7);
+
+	if(  gdk_color_parse (colorstr, &color) )
+		gtk_color_selection_set_current_color( 
+						GTK_COLOR_SELECTION(colorsel),
+						&color );
+	g_free( colorstr );
+
+	resp = gtk_dialog_run( GTK_DIALOG(colorselection) );
+
 	if( resp == GTK_RESPONSE_OK ){
 		gtk_color_selection_get_current_color(
 				GTK_COLOR_SELECTION(colorsel),
 				&color);
 		scicolor = gdk_color_to_scintilla_integer_color( &color );
 		*style = scicolor;
-		child = gtk_container_get_children (GTK_CONTAINER(button));
 		colorstr = gdk_color_to_rgb_triplet_string( &color );
 		markup = g_strdup_printf("<span background='%s'>    </span>",colorstr);
-		label = g_list_first( child )->data;
 		gtk_label_set_text(GTK_LABEL(label),markup);
 		gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
 		g_list_free( child );
