@@ -1,4 +1,4 @@
-/*  cssed (c) Iago Rubio 2003, 2004 - A tiny CSS editor.
+/*  cssed (c) Iago Rubio 2003, 2005 - A tiny CSS editor.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -262,6 +262,15 @@ create_preferences_dialog (CssedWindow * window, CssedConfig* tempconfig)
 	GtkWidget* apply_button;
 	GtkWidget* label_font;
 	GtkWidget* fontsel;
+	GtkWidget* vbox_other_settings;
+	GtkWidget* hbox_browser;	
+	GtkWidget* hbox_label;	
+	GtkWidget* entry_browser;
+	GtkWidget* label_browser;
+	GtkWidget* label_browser2;
+	GtkWidget* button_browser_apply;
+	GtkWidget* label_current_browser;
+	GtkWidget* label_other;
 	GtkWidget *dialog_action_area;
 	GtkWidget *cancelbutton;
 	GtkWidget *okbutton;
@@ -396,8 +405,7 @@ create_preferences_dialog (CssedWindow * window, CssedConfig* tempconfig)
 			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 			  (GtkAttachOptions) (0), 5, 5);
 	gtk_label_set_use_markup (GTK_LABEL (label_detail_defaults), TRUE);
-	gtk_label_set_justify (GTK_LABEL (label_detail_defaults),
-			       GTK_JUSTIFY_LEFT);
+	gtk_label_set_justify (GTK_LABEL (label_detail_defaults), GTK_JUSTIFY_LEFT);
 	gtk_misc_set_alignment (GTK_MISC (label_detail_defaults), 0, 0.5);
 
 	label_tab_doc_settings = gtk_label_new (_("<span size='medium'><b>Document settings</b></span>"));
@@ -1830,6 +1838,60 @@ create_preferences_dialog (CssedWindow * window, CssedConfig* tempconfig)
 				    label_font);
 	gtk_label_set_justify (GTK_LABEL (label_font),
 			       GTK_JUSTIFY_LEFT);	
+
+	
+	/* ********************************************************************* */
+	label_other = gtk_label_new (_("<span size='medium'><b>Other</b></span>"));
+	gtk_label_set_use_markup( GTK_LABEL(label_other), TRUE);
+	gtk_widget_show (label_other);	
+
+	vbox_other_settings = gtk_vbox_new(FALSE, 5);
+	gtk_widget_show (vbox_other_settings);
+
+	hbox_browser = gtk_hbox_new(FALSE, 5);
+	gtk_widget_show (hbox_browser);	
+
+	entry_browser = gtk_entry_new();
+	gtk_widget_show (entry_browser);	
+
+	button_browser_apply = gtk_button_new_with_label(_("Apply changes"));
+	gtk_widget_show (button_browser_apply);	
+
+	hbox_label = gtk_hbox_new(FALSE, 5);
+	gtk_widget_show (hbox_label);	
+
+	label_browser = gtk_label_new(_("Default browser command"));
+	gtk_widget_show (label_browser);	
+
+	label_browser2 = gtk_label_new(_("Current browser command: "));
+	gtk_widget_show (label_browser2);	
+
+	if( cfg->browser_command == NULL )
+		label_current_browser = gtk_label_new(_("None"));
+	else{
+		label_current_browser = gtk_label_new(cfg->browser_command);
+		gtk_entry_set_text(GTK_ENTRY(entry_browser), cfg->browser_command);
+	}
+	gtk_widget_show (label_current_browser);	
+
+	blank_label = gtk_label_new("");
+	gtk_widget_show(blank_label);
+
+	gtk_box_pack_start(GTK_BOX(hbox_browser), label_browser, FALSE, FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(hbox_browser), entry_browser, FALSE, TRUE, 5);
+	gtk_box_pack_start(GTK_BOX(hbox_browser), button_browser_apply, FALSE, FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(vbox_other_settings), hbox_browser, FALSE, FALSE, 5);
+
+	gtk_box_pack_start(GTK_BOX(hbox_label), label_browser2, FALSE, FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(hbox_label), label_current_browser, FALSE, FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(hbox_label), blank_label,TRUE,TRUE,5);
+
+	gtk_box_pack_start(GTK_BOX(vbox_other_settings), hbox_label, FALSE, FALSE, 5);
+
+	gtk_notebook_append_page        (GTK_NOTEBOOK(notebook),
+                                    vbox_other_settings,
+                                    label_other);
+
 	/* ******************** action area ******************* */
 	dialog_action_area = GTK_DIALOG (preferences_dialog)->action_area;
 	gtk_widget_show (dialog_action_area);
@@ -1847,7 +1909,11 @@ create_preferences_dialog (CssedWindow * window, CssedConfig* tempconfig)
 	gtk_dialog_add_action_widget (GTK_DIALOG (preferences_dialog),
 				      okbutton, GTK_RESPONSE_OK);
 	GTK_WIDGET_SET_FLAGS (okbutton, GTK_CAN_DEFAULT);
-	
+
+	/* ********************************************************************* */	
+	g_signal_connect ((gpointer) button_browser_apply, "clicked",
+					G_CALLBACK (on_apply_browser_button_clicked),window);
+	//
 	g_signal_connect ((gpointer) button_comment_fg, "clicked",
 					G_CALLBACK (on_button_comment_fg_clicked),window);
 	g_signal_connect ((gpointer) button_comment_bg, "clicked",
@@ -2043,11 +2109,18 @@ create_preferences_dialog (CssedWindow * window, CssedConfig* tempconfig)
 	g_signal_connect ((gpointer) apply_button, "clicked",
 			G_CALLBACK (on_apply_font_button_clicked),
 			window);
+	// browsers
+
 	/* Store pointers to some widgets, for use by lookup_widget(). */
 	GLADE_HOOKUP_OBJECT_NO_REF (preferences_dialog, preferences_dialog,
 				    "preferences_dialog");
 	GLADE_HOOKUP_OBJECT (preferences_dialog, notebook, "notebook");
+	//
+	GLADE_HOOKUP_OBJECT (preferences_dialog, entry_browser, "entry_browser");
+	GLADE_HOOKUP_OBJECT (preferences_dialog, label_current_browser, "label_current_browser");		
+	//
 	GLADE_HOOKUP_OBJECT (preferences_dialog, fontsel, "fontsel");
+
 	GLADE_HOOKUP_OBJECT (preferences_dialog, label_current, "label_current_font");
 	GLADE_HOOKUP_OBJECT (preferences_dialog, button_vproperty_fg,
 			     "button_vproperty_fg");				 
