@@ -1,4 +1,4 @@
-/*  cssed (c) Iago Rubio, 2003-2004 - A tiny CSS editor.
+/*  cssed (c) Iago Rubio, 2003-2005 - A tiny CSS editor.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,11 +21,10 @@
 #  include <config.h>
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <expat.h>
+#include <libxml/parser.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <stdarg.h>
 #include <fcntl.h>
 #include <string.h>
 #include <gtk/gtk.h>
@@ -35,17 +34,12 @@
 #endif
 
 #include "cssedwindow.h"
+#include "xmlparser.h"
 #include "support.h"
 #include "utils.h"
 #include "plugin.h"
 #include "debug.h"
 
-/* old spat stuff needed for BSD like machines as MacOsX*/
-#ifndef XML_STATUS_OK
-   #define XML_STATUS_OK    1
-   #define XML_STATUS_ERROR 0
-#endif
-
 enum {
 	PARSER_STATE_IN_START,
 	PARSER_STATE_IN_ROOT,
@@ -59,13 +53,70 @@ enum {
 
 /* protos */
 static void
-config_start_tag_cb (void* data, const char *el, const char **attr);
-
+config_start_tag_cb (void* data, const xmlChar *el, const xmlChar **attr);
 static void
-config_end_tag_cb (void *data, const char *el);
+config_end_tag_cb (void *data, const xmlChar *el);
+void
+parse_style_attributes (CssedConfigParserData* data, const xmlChar **attr);
+static void
+xml_error(void *user_data, const char *msg, ...);
 
 void
-parse_style_attributes( CssedConfigParserData* data, const char **attr);
+initialize_config_handler(xmlSAXHandler *handler)
+{
+	handler->internalSubset = NULL; 
+	handler->isStandalone = NULL;
+	handler->hasInternalSubset = NULL;
+	handler->hasExternalSubset = NULL;
+	handler->resolveEntity = NULL;
+	handler->getEntity = NULL;
+	handler->entityDecl = NULL;
+	handler->notationDecl = NULL;
+	handler->attributeDecl = NULL;
+	handler->elementDecl = NULL;
+	handler->unparsedEntityDecl = NULL;
+	handler->setDocumentLocator = NULL;
+	handler->startDocument = NULL;
+	handler->endDocument = NULL;
+	handler->startElement = config_start_tag_cb;
+	handler->endElement = config_end_tag_cb;
+	handler->reference = NULL;
+	handler->characters = NULL;
+	handler->ignorableWhitespace = NULL;
+	handler->processingInstruction = NULL;
+	handler->comment = NULL;
+	handler->warning = NULL;
+	handler->error = &xml_error;
+	handler->fatalError = NULL; /* unused error() get all the errors */
+	handler->getParameterEntity = NULL;
+	handler->cdataBlock = NULL;
+	handler->externalSubset = NULL;
+	handler->initialized = 0;
+	handler->_private = NULL;
+	handler->startElementNs = NULL;
+	handler->endElementNs = NULL;
+	handler->serror = NULL;
+}
+
+static void
+xml_error(void *user_data, const char *msg, ...) {
+	va_list args;
+	CssedWindow *window;
+	Tcssed_tp_data* data;
+	gchar *xmlerror;
+
+
+	data = (Tcssed_tp_data*) user_data;
+	window = CSSED_WINDOW(data->window);
+
+	va_start(args, msg);
+	xmlerror = g_strdup_vprintf(msg, args);
+	va_end(args);
+
+	g_strstrip(xmlerror);
+	cssed_error_message("Configuration file error", xmlerror);
+	g_free(xmlerror);
+}
 
 /* parse the css definition, it doesn't validate against the DTD yet
 	so ANY well formed XML will be parsed.
@@ -75,228 +126,140 @@ parse_style_attributes( CssedConfigParserData* data, const char **attr);
 GList*
 parse_configuration_file (CssedWindow* window)
 {
-	struct stat _stat;
-	int _retval;
+	gint retval;
 	gchar* configfile;
-	gchar* err ;
 	CssedConfigParserData* parser_data;
 	GList* plugins_list;
-	XML_Parser p;
-#ifdef WIN32
-	gchar* buffer;
-	GError* error = NULL;
-	gchar* allocated;
-#else
-	void* map;
-	int filedes;
-	gchar* home;
-#endif
+	G_CONST_RETURN gchar* home;
+	xmlSAXHandler handler;
 
-	parser_data = g_malloc( sizeof(CssedConfigParserData));
+	initialize_config_handler(&handler);
+
+	parser_data = g_malloc(sizeof(CssedConfigParserData));
 	parser_data->window = window;
 	parser_data->depth = 0;
 	parser_data->state = PARSER_STATE_IN_START;
 	parser_data->plugins_list = NULL;
 
-#ifdef WIN32
-	configfile = g_strdup("data\\cssed-cfg.xml");
-	if( !g_file_test(configfile,G_FILE_TEST_IS_REGULAR| G_FILE_TEST_EXISTS) ){
-		return NULL; // no configuration yet
-	}
-#else
-	home = getenv("HOME");
+	home = g_get_home_dir();
 	if( home != NULL ){
-		configfile = g_strconcat(home,"/.cssed/cssed-cfg.xml",NULL);
-		if( !g_file_test(configfile,G_FILE_TEST_IS_REGULAR| G_FILE_TEST_EXISTS) ){
+		configfile = g_strconcat(home, G_DIR_SEPARATOR_S, ".cssed", G_DIR_SEPARATOR_S, "cssed-cfg.xml",NULL );
+	if( !g_file_test(configfile,G_FILE_TEST_IS_REGULAR| G_FILE_TEST_EXISTS) )
 			return NULL; // no configuration yet
-		}
 	}else{
 		return NULL; // no home so no configuration file
 	}
-#endif
-	DBGMSG("User's config exist: %s", configfile );
-	_retval = stat( configfile , &_stat );
-	if( _retval != 0 ){
-		cssed_error_message( _("Cannot stat on configuration file!!!") , _("Error") );
-  	}else{
-#ifdef WIN32
-		if( !g_file_get_contents (configfile,
-									&buffer,
-									NULL,
-                                    &error) ){
-			cssed_error_message( "Can't open configuration file" , "Error" );
-			return FALSE;
-
-		}
-
-		allocated = g_strdup( buffer );
-
-		p = XML_ParserCreate (NULL);
-		if (!p)
-		{
-			cssed_error_message( "Can't allocate memory for XML parser !!!" , "Error" );
-			return FALSE;
-		}
-
-		XML_SetElementHandler (p, config_start_tag_cb, config_end_tag_cb);
-		XML_SetUserData( p, (void *) parser_data);
-
-		if (XML_Parse (p, (char*) allocated, _stat.st_size, 1) == XML_STATUS_ERROR)
-		{
-			err = g_strdup_printf(
-				"The configuration XML file is bogus.\nFile: %s\nParse error at line %d:\n%s\n",
-				configfile,
-				XML_GetCurrentLineNumber (p),
-				XML_ErrorString (XML_GetErrorCode (p))
-				);
-			cssed_error_message	(err,"Configuration error" );
-			g_free(err);
-		}
-		g_free( allocated );
-#else
-			if( S_ISREG( _stat.st_mode ) ){
-	  		if( (filedes = open(configfile, O_RDONLY)) < 0){
-				cssed_error_message( _("Cannot open configuration file!!!") , _("Error") );
-	  		}else{
-				if( (map = mmap(0,_stat.st_size, PROT_READ, MAP_SHARED, filedes, 0)) == MAP_FAILED ){
-		  			cssed_error_message( _("Cannot map configuration file to memory!!!") , _("Error") );
-		  			close(filedes);
-					return NULL;
-				}else{
-					p = XML_ParserCreate (NULL);
-					if (!p)
-					{
-						cssed_error_message( _("Cannot allocate memory for XML parser!!!") , _("Error") );
-						munmap(map,_stat.st_size );
-						close(filedes);
-						return NULL;
-					}
-
-					XML_SetElementHandler (p, config_start_tag_cb, config_end_tag_cb);
-					XML_SetUserData( p, (void *) parser_data);
-
-					if (XML_Parse (p, (char*) map, _stat.st_size, 1) == XML_STATUS_ERROR)
-					{
-						err = g_strdup_printf(
-							_("The configuration XML file is bogus.\nFile: %s\nParse error at line %d:\n%s\n"),
+	DBGMSG (__FILE__,__LINE__,"User's config exist: %s", configfile );
+	if ( (retval=xmlSAXUserParseFile(&handler, parser_data, configfile)) != 0 ) {
+		cssed_error_message(_("Error parsing XML definition file"), 
+							_("The parser found error on the xml file\n%s\n\nError code: %d."),
 							configfile,
-							XML_GetCurrentLineNumber (p),
-						 	XML_ErrorString (XML_GetErrorCode (p))
-							);
-						cssed_error_message	(err, _("Configuration error") );
-						g_free(err);
-						return NULL;
-					}
-					XML_ParserFree(p);
-				}
-				munmap(map,_stat.st_size);
-				close(filedes);
-			}
-			}
-#endif
-	}
-	if( parser_data->plugins_list  != NULL ){
-		DBGMSG( "config plugins: %d", g_list_length( parser_data->plugins_list ));
-		plugins_list = g_list_copy(  parser_data->plugins_list  );
-		DBGMSG( "config will return: %d - %p", g_list_length( parser_data->plugins_list ), plugins_list);
-		g_list_free( parser_data->plugins_list );
-		g_free( parser_data );
-		g_free( configfile );
+							retval);
+		return NULL;
+	} 
+
+	if( parser_data->state != PARSER_STATE_ERROR && parser_data->plugins_list != NULL ){
+		DBGMSG (__FILE__,__LINE__,"config plugins: %d", g_list_length(parser_data->plugins_list));
+		plugins_list = parser_data->plugins_list;
+		DBGMSG (__FILE__,__LINE__,"config will return: %d - %p", g_list_length( parser_data->plugins_list ), plugins_list);
+		g_free(parser_data);
+		g_free(configfile);
 		return plugins_list;
 	}else{
-		g_free( parser_data );
-		g_free( configfile );
+		g_free(parser_data);
+		g_free(configfile);
 		return NULL;
 	}
 }
 
 static void
-config_start_tag_cb (void* data, const char *el, const char **attr)
+config_start_tag_cb (void* data, const xmlChar *el, const xmlChar **attr)
 {
 	gint i;
-	gchar* err_depth;
 	CssedWindow* window;
 	CssedConfigParserData* tp_data;
 	CssedConfig* cfg;
 
 	tp_data = (CssedConfigParserData*) data;
 	window = tp_data->window;
-	cfg = cssed_window_get_config( window );
-	// FIXME check parser state
-	//if( data->state == PARSER_STATE_ERROR) return;
+	cfg = cssed_window_get_config(window);
+
+	if( tp_data->state == PARSER_STATE_ERROR) return;
 
 	switch( tp_data->depth ){
 		case 0: //
-				if( strcmp( el, "cssed-cfg")!=0){
+				if( strcmp(el, "cssed-conf")!=0 )
 					tp_data->state = PARSER_STATE_ERROR;
-				}else{
+				else
 					tp_data->state = PARSER_STATE_IN_ROOT;
-				}
 		break;
 		case 1: //
-			if( tp_data->state != PARSER_STATE_IN_ROOT ){
+			if( tp_data->state != PARSER_STATE_IN_ROOT )
 				tp_data->state = PARSER_STATE_ERROR;
-			}
-			if( strcmp( el, "window") == 0){
+
+			if( strcmp(el, "window") == 0){
 				tp_data->state = PARSER_STATE_IN_WINDOW;				
 				for (i = 0; attr[i]; i += 2)
 				{  
-					if( strcmp( attr[i], "x")==0){	
-						if( char_ptr_is_decimal_num(attr[i + 1]) ){
+					if( strcmp(attr[i], "x")==0){	
+						if( char_ptr_is_decimal_num(attr[i + 1]) )
 							cfg->window_x = atoi(attr[i + 1]);
-						}
-					}else if( strcmp( attr[i], "y")==0){	
-						if( char_ptr_is_decimal_num(attr[i + 1]) ){
+					}else if( strcmp(attr[i], "y")==0){	
+						if( char_ptr_is_decimal_num(attr[i + 1]) )
 							cfg->window_y = atoi(attr[i + 1]);
-						}
-					}else if( strcmp( attr[i], "width")==0){
-						if( char_ptr_is_decimal_num(attr[i + 1]) ){
+					}else if( strcmp(attr[i], "width")==0){
+						if( char_ptr_is_decimal_num(attr[i + 1]) )
 							cfg->window_width = atoi(attr[i + 1]);
-						}
-					}else if( strcmp( attr[i], "height")==0){
-						if( char_ptr_is_decimal_num(attr[i + 1]) ){
+					}else if( strcmp(attr[i], "height")==0){
+						if( char_ptr_is_decimal_num(attr[i + 1]) )
 							cfg->window_height = atoi(attr[i + 1]);
-						}
+					}else if( strcmp(attr[i], "maximized")==0){
+						if( strcmp(attr[i + 1], "true" ) == 0 )
+							cfg->initiall_state_maximized = TRUE;
+						else
+							cfg->initiall_state_maximized = FALSE;
 					}else{
 						tp_data->state = PARSER_STATE_ERROR;
 					}
 				}
-			}else if( strcmp( el, "document") == 0 ){
+			}else if( strcmp(el, "document") == 0 )
 				tp_data->state = PARSER_STATE_IN_DOCUMENT;
-			}else if( strcmp( el, "opened-docs") == 0 ){
+			else if( strcmp(el, "opened-docs") == 0 )
 				tp_data->state = PARSER_STATE_IN_OPENED_DOCS;
-			}else if( strcmp( el, "highlighting") == 0 ){
+			else if( strcmp(el, "highlighting") == 0 )
 				tp_data->state = PARSER_STATE_IN_HIGHLIGHTING;
-			}else if( strcmp( el, "plugins") == 0 ){
+			else if( strcmp(el, "plugins") == 0 )
 				tp_data->state = PARSER_STATE_IN_PLUGINS;
-			}else{
-				tp_data->state = PARSER_STATE_ERROR;
+			else if( strcmp(el, "browser") == 0 ){
+				for (i = 0; attr[i]; i += 2)
+				{  
+					if( strcmp(attr[i], "command") == 0){
+						cfg->browser_command = g_strdup(attr[i + 1]);
+					}
+					tp_data->state = PARSER_STATE_IN_ROOT;
+				}
 			}
+			else
+				tp_data->state = PARSER_STATE_ERROR;
 		break;
 		case 2: // 
 			switch( tp_data->state ){
 				case PARSER_STATE_IN_WINDOW:
-					if( strcmp( el, "notebook" ) == 0){
-						if( strcmp( attr[0], "height") == 0 ){
-							if( char_ptr_is_decimal_num(attr[1]) ){
-								cfg->notebook_height = atoi(attr[1]);
-							}
+					if( strcmp(el, "footer") == 0){
+						if( strcmp(attr[0], "position") == 0 ){
+							if( char_ptr_is_decimal_num(attr[1]) )	cfg->footer_pos = atoi(attr[1]);							
 						}else{
 							tp_data->state = PARSER_STATE_ERROR;
 						}
-					}else if( strcmp( el, "sidebar" ) == 0){
-						if( strcmp( attr[0], "width") == 0 ){
-							if( char_ptr_is_decimal_num(attr[1]) ){
-								cfg->sidebar_width = atoi(attr[1]);
-							}
+					}else if( strcmp(el, "sidebar" ) == 0){
+						if( strcmp(attr[0], "position") == 0 ){
+							if( char_ptr_is_decimal_num(attr[1]) ) cfg->sidebar_pos = atoi(attr[1]);
 						}else{
 							tp_data->state = PARSER_STATE_ERROR;
 						}
-					}else if( strcmp( el, "treeview" ) == 0){	
-						if( strcmp( attr[0], "height") == 0 ){
-							if( char_ptr_is_decimal_num(attr[1]) ){
-								cfg->treeview_height = atoi(attr[1]);
-							}
+					}else if( strcmp(el, "csstreeview" ) == 0){	
+						if( strcmp(attr[0], "position") == 0 ){
+							if( char_ptr_is_decimal_num(attr[1]) ) cfg->css_treeview_pos = atoi(attr[1]);
 						}else{
 							tp_data->state = PARSER_STATE_ERROR;
 						}
@@ -305,84 +268,77 @@ config_start_tag_cb (void* data, const char *el, const char **attr)
 					}
 					break;
 				case PARSER_STATE_IN_DOCUMENT:
-					if( strcmp( el, "linenumbers" ) == 0){
-						if( strcmp( attr[0], "show") == 0 ){
-							if( strcmp( attr[1], "true" ) == 0 ){
+					if( strcmp(el, "linenumbers" ) == 0){
+						if( strcmp(attr[0], "show") == 0 ){
+							if( strcmp(attr[1], "true" ) == 0 )
 								cfg->linenumbers = TRUE;
-							}else{
+							else
 								cfg->linenumbers = FALSE;
-							}
 						}else{
 							tp_data->state = PARSER_STATE_ERROR;
 						}
-					}else if( strcmp( el, "autocompletion" ) == 0){
-						if( strcmp( attr[0], "enabled") == 0 ){
-							if( strcmp( attr[1], "true" ) == 0 ){
+					}else if( strcmp(el, "autocompletion" ) == 0){
+						if( strcmp(attr[0], "enabled") == 0 ){
+							if( strcmp(attr[1], "true" ) == 0 )
 								cfg->autocompletion = TRUE;
-							}else{
+							else
 								cfg->autocompletion = FALSE;
-							}	
 						}else{
 							tp_data->state = PARSER_STATE_ERROR;
 						}
-					}else if( strcmp( el, "lineendings" ) == 0){	
-						if( strcmp( attr[0], "show") == 0 ){
-							if( strcmp( attr[1], "true" ) == 0 ){
+					}else if( strcmp(el, "lineendings" ) == 0){	
+						if( strcmp(attr[0], "show") == 0 ){
+							if( strcmp(attr[1], "true" ) == 0 )
 								cfg->lineendings = TRUE;
-							}else{
+							else
 								cfg->lineendings = FALSE;
-							}	
 						}else{
 							tp_data->state = PARSER_STATE_ERROR;
 						}
-					}else if( strcmp( el, "whitespaces" ) == 0){	
-						if( strcmp( attr[0], "show") == 0 ){
-							if( strcmp( attr[1], "true" ) == 0 ){
+					}else if( strcmp(el, "whitespaces" ) == 0){	
+						if( strcmp(attr[0], "show") == 0 ){
+							if( strcmp(attr[1], "true" ) == 0 )
 								cfg->whitespaces = TRUE;
-							}else{
+							else
 								cfg->whitespaces = FALSE;
-							}	
 						}else{
 							tp_data->state = PARSER_STATE_ERROR;
 						}
-					}else if( strcmp( el, "folding" ) == 0){	
-						if( strcmp( attr[0], "enabled") == 0 ){
-							if( strcmp( attr[1], "true" ) == 0 ){
+					}else if( strcmp(el, "folding" ) == 0){	
+						if( strcmp(attr[0], "enabled") == 0 ){
+							if( strcmp(attr[1], "true" ) == 0 )
 								cfg->folding = TRUE;
-							}else{
+							else
 								cfg->folding = FALSE;
-							}	
 						}else{
 							tp_data->state = PARSER_STATE_ERROR;
 						}	
-					}else if( strcmp( el, "lineswraped" ) == 0){	
-						if( strcmp( attr[0], "show") == 0 ){
-							if( strcmp( attr[1], "true" ) == 0 ){
+					}else if( strcmp(el, "lineswraped" ) == 0){	
+						if( strcmp(attr[0], "show") == 0 ){
+							if( strcmp(attr[1], "true" ) == 0 )
 								cfg->lineswraped = TRUE;
-							}else{
+							else
 								cfg->lineswraped = FALSE;
-							}	
 						}else{
 							tp_data->state = PARSER_STATE_ERROR;
 						}							
-					}else if( strcmp( el, "font" ) == 0){	
+					}else if( strcmp(el, "font" ) == 0){	
 						for (i = 0; attr[i]; i += 2)
 						{ 
-							if( strcmp( attr[i], "name") == 0 ){
-									cfg->font = g_strdup(attr[i+1]);
-							}else if( strcmp( attr[i], "size") == 0 ){
-									cfg->font_size = atoi(attr[i+1]);
-							}else{
+							if( strcmp(attr[i], "name") == 0 )
+								cfg->font = g_strdup(attr[i+1]);
+							else if( strcmp(attr[i], "size") == 0 )
+								cfg->font_size = atoi(attr[i+1]);
+							else
 								tp_data->state = PARSER_STATE_ERROR;
-							}	
 						}
 					}else{
 						tp_data->state = PARSER_STATE_ERROR;
 					}
 					break;
 				case PARSER_STATE_IN_OPENED_DOCS: // UNFINISHED FIXME 
-					if( strcmp( el, "doc" ) == 0){
-						if( strcmp( attr[0], "path") == 0 ){
+					if( strcmp(el, "doc") == 0){
+						if( strcmp(attr[0], "path") == 0 ){
 							// value attr[1] true
 						}else{
 							tp_data->state = PARSER_STATE_ERROR;
@@ -392,9 +348,9 @@ config_start_tag_cb (void* data, const char *el, const char **attr)
 					}
 					break;
 				case PARSER_STATE_IN_PLUGINS: // UNFINISHED FIXME 
-					if( strcmp( el, "plugin" ) == 0){
-						if( strcmp( attr[0], "file") == 0 ){
-							DBGMSG( "config read plugin found file:\n%s", attr[1] );
+					if( strcmp(el, "plugin" ) == 0){
+						if( strcmp(attr[0], "file") == 0 ){
+							DBGMSG (__FILE__,__LINE__, "config read plugin found file: %s", attr[1] );
 							tp_data->plugins_list = g_list_append( tp_data->plugins_list, g_strdup( attr[1] ) );
 						}else{
 							tp_data->state = PARSER_STATE_ERROR;
@@ -404,11 +360,10 @@ config_start_tag_cb (void* data, const char *el, const char **attr)
 					}
 					break;					
 				case PARSER_STATE_IN_HIGHLIGHTING:
-					if( strcmp( el, "style" ) == 0){
+					if( strcmp(el, "style" ) == 0)
 						parse_style_attributes( tp_data, attr );
-					}else{
+					else
 						tp_data->state = PARSER_STATE_ERROR;
-					}
 					break;
 				default:
 					tp_data->state = PARSER_STATE_ERROR;
@@ -417,11 +372,9 @@ config_start_tag_cb (void* data, const char *el, const char **attr)
 		break;
 		default:
 			// it must go out here
-			err_depth = g_strdup_printf( 
-							_("Bad XML configuration file\nDepth %d at element %s\nMax deptph must be 3"),
-							tp_data->depth, el);
-			cssed_error_message (err_depth, _("Configuration file error"));
-			g_free(err_depth);
+			cssed_error_message (_("Configuration file error"), 
+								 _("Bad XML configuration file\nDepth %d at element %s\nMax deptph must be 3"),
+								 tp_data->depth, el);
 			tp_data->state = PARSER_STATE_ERROR;
 		break;
 	}
@@ -429,7 +382,7 @@ config_start_tag_cb (void* data, const char *el, const char **attr)
 }
 
 static void
-config_end_tag_cb (void *data, const char *el)
+config_end_tag_cb (void *data, const xmlChar *el)
 {
 	CssedConfigParserData* pdata;
 	
@@ -438,7 +391,7 @@ config_end_tag_cb (void *data, const char *el)
 }
 
 void
-parse_style_attributes( CssedConfigParserData* data, const char **attr)
+parse_style_attributes( CssedConfigParserData* data, const xmlChar **attr)
 {
 	CssedWindow* window;
 	CssedConfig* cfg;
@@ -454,19 +407,19 @@ parse_style_attributes( CssedConfigParserData* data, const char **attr)
 	
 	for (i = 0; attr[i]; i += 2)
 	{
-		if( strcmp( attr[i], "name")==0){				
+		if( strcmp(attr[i], "name")==0){				
 			value = attr[i + 1];			
-		}else if( strcmp( attr[i], "fore")==0 ){			
+		}else if( strcmp(attr[i], "fore")==0 ){			
 			fore = strtol(attr[i + 1], NULL, 16);
 			if( fore == LONG_MIN || fore == LONG_MAX ){
 				fore = -1; // out of range
 			}
-		}else if( strcmp( attr[i], "back")==0 ){
+		}else if( strcmp(attr[i], "back")==0 ){
 			back = strtol(attr[i + 1], NULL, 16);
 			if( back == LONG_MIN || back == LONG_MAX ){
 				back = -1; // out of range
 			}			
-		}else if( strcmp( attr[i], "bold")==0 ){
+		}else if( strcmp(attr[i], "bold")==0 ){
 			bold = (strcmp(attr[i + 1], "true" )==0)?TRUE:FALSE;
 			bold_found = TRUE;
 		}
@@ -477,7 +430,7 @@ parse_style_attributes( CssedConfigParserData* data, const char **attr)
 		return;
 	}
 	
-	if( strcmp( value,"DEFAULT") == 0){
+	if( strcmp(value,"DEFAULT") == 0){
 		if( fore >= 0 && fore <= 0xffffff )
 			cfg->DEFAULT_fore_color = fore;
 		if( back >= 0 && back <= 0xffffff )
