@@ -1,4 +1,4 @@
-/*  cssed (c) Iago Rubio 2003, 2004 - A tiny CSS editor.
+/*  cssed (c) Iago Rubio 2003, 2005 - A tiny CSS editor.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -60,7 +60,11 @@ on_angle_property_dialog_ok_button_clicked (GtkButton * button, gpointer user_da
 		document_add_text (tmpdoc, output_string);
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (output_string);
@@ -102,7 +106,11 @@ void on_background_property_dialog_okbutton_clicked
 		document_add_text (tmpdoc, output_string);    
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (output_string);
@@ -149,7 +157,11 @@ on_border_properties_okbutton_clicked (GtkButton * button, gpointer user_data)
 
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (output_string);
@@ -195,7 +207,11 @@ void on_border_width_properties_dialog_okbutton_clicked
 
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (output_string);
@@ -240,7 +256,11 @@ void on_border_width_single_okbutton_clicked
 
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (output_string);
@@ -338,7 +358,11 @@ void on_dialog_counter_increment_reset_okbutton_clicked
 
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (output_string);
@@ -382,7 +406,11 @@ void on_string_properties_dialog_okbutton_clicked
 		document_add_text (tmpdoc, output_string);
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (output_string);
@@ -432,7 +460,11 @@ on_uri_value_dialog_okbutton_clicked (GtkButton * button, gpointer user_data)
 
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (output_string);
@@ -443,8 +475,7 @@ on_uri_value_dialog_okbutton_clicked (GtkButton * button, gpointer user_data)
 	else
 	{
 		document_write_error_to_program_output (tmpdoc,
-							_
-							("uri dialog: rejecting to add empty values"),
+							_("uri dialog: rejecting to add empty values"),
 							ERROR_COLOR_STRING);
 	}
 }
@@ -481,7 +512,11 @@ on_attr_value_dialog_okbutton_clicked (GtkButton * button, gpointer user_data)
 		document_add_text (tmpdoc, output_string);
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (output_string);
@@ -532,7 +567,11 @@ void on_counter_property_dialog_okbutton_clicked
 		document_add_text (tmpdoc, output_string);
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (data->previous_string);
@@ -582,7 +621,11 @@ void on_font_property_dialog_okbutton_clicked
 		document_add_text (tmpdoc, output_string);
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		g_free (output_string);
 	}
@@ -683,7 +726,11 @@ void on_font_family_dialog_okbutton_clicked
 		document_add_text (tmpdoc, output_string);
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (output_string);
@@ -877,7 +924,11 @@ void on_identifier_value_dialog_okbutton_clicked
 		document_add_text (tmpdoc, output_string);
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (output_string);
@@ -1024,7 +1075,11 @@ void on_list_style_dialog_okbutton_clicked
 
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);                                     
 
@@ -1085,7 +1140,11 @@ void on_margin_property_dialog_okbutton_clicked
 
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 
@@ -1217,7 +1276,11 @@ void on_padding_property_dialog_okbutton_clicked
 		document_add_text (tmpdoc, "0");
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 	}
@@ -1233,7 +1296,11 @@ void on_padding_property_dialog_okbutton_clicked
 		document_add_text (tmpdoc, output_string);
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (output_string);
@@ -1285,7 +1352,11 @@ void on_outline_property_dialog_okbutton_clicked
 		document_add_text (tmpdoc, output_string);
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 
@@ -1336,7 +1407,11 @@ void on_pause_property_dialog_okbutton_clicked
 		document_add_text (tmpdoc, output_string);
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 
@@ -1466,7 +1541,11 @@ void on_play_during_property_dialog_okbutton_clicked
 
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 
@@ -1584,7 +1663,11 @@ void on_quotes_property_dialog_okbutton_clicked
 		document_add_text (tmpdoc, output_string);
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (output_string);
@@ -1885,7 +1968,11 @@ void on_text_shadow_value_dialog_okbutton_clicked
 		document_add_text (tmpdoc, output_string);
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 		g_free (output_string);
@@ -2002,7 +2089,11 @@ void on_voice_family_value_dialog_okbutton_clicked
 		document_add_text (tmpdoc, output_string);
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		g_free (output_string);
 		g_free (data->previous_string);
@@ -2060,7 +2151,11 @@ void on_border_width_style_color_value_dialog_okbutton_clicked
 
 		if (add_previous)
 		{
-			document_add_text (tmpdoc, ";\n\t");
+			document_add_text (tmpdoc, ";\n");
+			if( document_last_line_is_indented(tmpdoc) )
+				document_indent_as_last_line(tmpdoc);
+			else
+				document_add_text (tmpdoc, "\t");
 		}
 		//document_new_undo_action(tmpdoc);
 
