@@ -1,4 +1,4 @@
-/*  cssed (c) Iago Rubio 2003, 2004 - A tiny CSS editor.
+/*  cssed (c) Iago Rubio 2003, 2005 - A tiny CSS editor.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 	and using just it's SAC handler. Don't use it as a libcroco example as
 	the libcroco used IS MODIFIED. Some functions doesn't exists or are private
 	in the original libcroco. 
-	
+
 	Download the original libcroco from http://www.freespiders.org/
 */
 
@@ -33,10 +33,6 @@
 #include <stdio.h>
 #include <gtk/gtk.h>
 
-#ifdef WITH_TERMINAL
- #include <vte/vte.h>
-#endif
-
 #include "cssedwindow.h"
 #include "document.h"
 #include "callbacks.h"
@@ -54,10 +50,11 @@
 #define MED_COLOR "dark green"
 
 typedef struct _CssedCssParserData {
-	CssedDoc* doc;
-	gchar* current_selector;
+	CssedDoc *doc;
+	gchar *current_selector;
 	gboolean in_media;
 	gint err_count;
+	gchar *filename;
 } CssedCssParserData;
 	
 /* *** UTILS *** */
@@ -70,7 +67,7 @@ get_window_fom_sac_handler_data (CRDocHandler * a_handler)
 
 	data = (CssedCssParserData*) a_handler->app_data;
 	document = (CssedDoc *) data->doc;
-	win = document_get_window ( document );
+	win = document_get_window (document);
 
 	return win;
 }
@@ -84,48 +81,57 @@ change_current_sac_handler_selector(CRDocHandler * a_handler,gchar* selector)
 	if( data->current_selector )
 		g_free(data->current_selector);
 	
-	data->current_selector = g_strdup( selector );	
+	data->current_selector = g_strdup(selector);	
 }
 
 /* *** SAC HANDLERS START *** */
-static void
+void
 sac_handler_start_document (CRDocHandler * a_handler)
 {
 	CssedWindow* window;
 	g_return_if_fail (a_handler);
 
 	window = get_window_fom_sac_handler_data (a_handler);
-	cssed_window_output_clear( window );
+	cssed_window_output_clear(window);
 }
 
-static void
+void
 sac_handler_end_document (CRDocHandler * a_handler)
 {
 	g_return_if_fail (a_handler);
 }
 
-static void
-sac_handler_import_style (CRDocHandler * a_handler, GList * a_media_list,
-			  GString * a_uri, GString * a_uri_default_ns)
+void
+sac_handler_import_style (CRDocHandler *a_handler,
+						  GList *a_media_list,
+						  CRString *ar_uri,
+						  CRString *ar_uri_default_ns,
+						  CRParsingLocation *a_location)
 {
 	GList *cur = NULL;
 	guchar *str;
 	guchar *out;
 	CssedCssParserData* data;
+	GString *a_uri, *a_uri_default_ns;
 
+
+	g_return_if_fail (ar_uri);
+	g_return_if_fail (ar_uri_default_ns);	
 	g_return_if_fail (a_handler);
-	data = (CssedCssParserData*) a_handler->app_data	;
 
-	document_write_error_to_program_output ((CssedDoc *) data->
-						doc,
-						"Input style from import found.",
+	a_uri = ar_uri->stryng;
+	a_uri_default_ns = ar_uri_default_ns->stryng;
+
+	data = (CssedCssParserData*) a_handler->app_data;
+
+	document_write_error_to_program_output ((CssedDoc *) data->doc,
+						_("Input style from import found."),
 						OUT_COLOR);
 
 	if (a_media_list)
 	{
-		document_write_error_to_program_output ((CssedDoc *)
-							data->doc,
-							"\tMedia list",
+		document_write_error_to_program_output ((CssedDoc *) data->doc,
+							_("\tMedia list"),
 							OUT_COLOR);
 
 		for (cur = a_media_list; cur; cur = cur->next)
@@ -139,9 +145,7 @@ sac_handler_import_style (CRDocHandler * a_handler, GList * a_media_list,
 				if (str)
 				{
 					out = g_strdup_printf ("\t\t%s", str);
-					document_write_error_to_program_output
-						((CssedDoc *) data->
-						 doc, out, OUT_COLOR);
+					document_write_error_to_program_output((CssedDoc *) data->doc, out, OUT_COLOR);
 					g_free (str);
 					g_free (out);
 					str = NULL;
@@ -150,60 +154,60 @@ sac_handler_import_style (CRDocHandler * a_handler, GList * a_media_list,
 			}
 		}
 
-		document_write_error_to_program_output ((CssedDoc *)
-							data->doc,
-							"\tDefault namespace",
-							OUT_COLOR);
+		document_write_error_to_program_output ((CssedDoc *)data->doc, _("\tDefault namespace"), OUT_COLOR);
 		if (a_uri_default_ns && a_uri_default_ns->str)
 		{
-			str = g_strndup (a_uri_default_ns->str,
-					 a_uri_default_ns->len);
+			str = g_strndup (a_uri_default_ns->str, a_uri_default_ns->len);
 			if (str)
 			{
 				out = g_strdup_printf ("\t\t%s", str);
 				document_write_error_to_program_output ((CssedDoc *) data->doc, out, OUT_COLOR);
 				g_free (str);
 				g_free (out);
-				str = NULL;
-				out = NULL;
 			}
 		}
 	}
-	a_uri = NULL;		/*keep compiler happy */
 }
 
 
-static void
-sac_handler_namespace_declaration (CRDocHandler * a_handler,
-				   GString * a_prefix, GString * a_uri)
+void
+sac_handler_namespace_declaration (CRDocHandler *a_handler,
+								   CRString *ar_prefix,
+								   CRString *ar_uri,
+								   CRParsingLocation *a_location)
+
 {
+	GString *a_prefix, *a_uri;
 	guchar *prefix = NULL;
 	guchar *uri = NULL;
 	guchar *out = NULL;
 	CssedCssParserData* data;
 
-	g_return_if_fail (a_handler);
-	data = (CssedCssParserData*) a_handler->app_data;	
 
-	document_write_error_to_program_output ((CssedDoc *) data->
-						doc,
-						"parser: Namespace declaration",
-						OUT_COLOR);
+	g_return_if_fail (ar_uri);
+	g_return_if_fail (ar_prefix);	
+	g_return_if_fail (a_handler);
+
+	data = (CssedCssParserData*) a_handler->app_data;	
+	a_prefix = ar_prefix->stryng;
+	a_uri = ar_uri->stryng;
+
+	document_write_error_to_program_output ((CssedDoc *) data->doc,
+						_("parser: Namespace declaration"),	OUT_COLOR);
+
 	if (a_prefix && a_prefix->str)
 	{
 		prefix = g_strndup (a_prefix->str, a_prefix->len);
 
 		if (prefix)
 		{
-			out = g_strdup_printf ("\t\tprefix: %s", prefix);
+			out = g_strdup_printf (_("\t\tprefix: %s"), prefix);
 			document_write_error_to_program_output ((CssedDoc *)
 								data->
 								doc, out,
 								OUT_COLOR);
 			g_free (prefix);
 			g_free (out);
-			out = NULL;
-			prefix = NULL;
 		}
 	}
 
@@ -214,42 +218,40 @@ sac_handler_namespace_declaration (CRDocHandler * a_handler,
 
 		if (uri)
 		{
-			out = g_strdup_printf ("\t\turi: %s", uri);
+			out = g_strdup_printf (_("\t\turi: %s"), uri);
 			document_write_error_to_program_output ((CssedDoc *)
 								data->
 								doc, out,
 								OUT_COLOR);
 			g_free (prefix);
 			g_free (out);
-			out = NULL;
-			prefix = NULL;
 		}
 	}
 }
 
 
-static void
-sac_handler_comment (CRDocHandler * a_handler, GString * a_comment)
+void
+sac_handler_comment    (CRDocHandler *a_handler,
+						CRString *ar_comment) 
 {
 	gchar *out = NULL;
 	guchar *comment = NULL;
 	CssedCssParserData* data;
+	GString * a_comment;
 
+	g_return_if_fail (ar_comment);	
 	g_return_if_fail (a_handler);
+
 	data = (CssedCssParserData*) a_handler->app_data;	
-	
+	a_comment = ar_comment->stryng;
 	if (a_comment && a_comment->str)
 	{
 		comment = g_strndup (a_comment->str, a_comment->len);
 
 		if (comment)
 		{
-			out = g_strdup_printf ("comment -> %s",
-					       comment);
-			document_write_error_to_program_output ((CssedDoc *)
-								data->
-								doc, out,
-								OUT_COLOR);
+			out = g_strdup_printf (_("comment -> %s"), comment);
+			document_write_error_to_program_output ((CssedDoc*) data->doc, out,	OUT_COLOR);
 			g_free (comment);
 			g_free (out);
 			out = NULL;
@@ -259,16 +261,18 @@ sac_handler_comment (CRDocHandler * a_handler, GString * a_comment)
 }
 
 
-
-static void
+void
 sac_handler_start_selector (CRDocHandler * a_handler,
-			    CRSelector * a_selector_list)
+							CRSelector * a_selector_list)
 {
 	guchar *tmp_buf = NULL;
 	gchar *out = NULL;
 	CssedCssParserData* data;
 
+
+	g_return_if_fail (a_selector_list);	
 	g_return_if_fail (a_handler);
+
 	data = (CssedCssParserData*) a_handler->app_data;	
 
 	if (a_selector_list)
@@ -277,29 +281,29 @@ sac_handler_start_selector (CRDocHandler * a_handler,
 		if (tmp_buf)
 		{
 			data->current_selector = g_strdup(tmp_buf);
-			out = g_strdup_printf ("%s", tmp_buf);
-			document_write_error_to_program_output ((CssedDoc *)
-								data->
-								doc, out,
-								SEL_COLOR);
+			out = g_strdup_printf (_("<span color='black'>%s</span>:<span color='dark green'>%d</span>:\n%s"), 
+															data->filename, 
+															a_selector_list->location.line,
+															tmp_buf);
+			document_write_error_to_program_output ((CssedDoc*) data->doc, out, SEL_COLOR);
 			g_free (out);
 			g_free (tmp_buf);
-			tmp_buf = NULL;
-			out = NULL;
 		}
 	}
 }
 
 
-static void
-sac_handler_end_selector (CRDocHandler * a_handler,
-			  CRSelector * a_selector_list)
+void
+sac_handler_end_selector   (CRDocHandler * a_handler,
+							CRSelector * a_selector_list)
 {
 	guchar *tmp_buf = NULL;
 	gchar *out = NULL;
 	CssedCssParserData* data;
 
+	g_return_if_fail (a_selector_list);	
 	g_return_if_fail (a_handler);
+
 	data = (CssedCssParserData*) a_handler->app_data;	
 
 	if (a_selector_list)
@@ -307,11 +311,8 @@ sac_handler_end_selector (CRDocHandler * a_handler,
 		tmp_buf = cr_selector_to_string (a_selector_list);
 		if (tmp_buf)
 		{
-			out = g_strdup_printf ("%s end", tmp_buf);
-			document_write_error_to_program_output ((CssedDoc *)
-								data->
-								doc, out,
-								SEL_COLOR);
+			out = g_strdup_printf (_("%s end"), tmp_buf);
+			document_write_error_to_program_output ((CssedDoc*) data-> doc, out, SEL_COLOR);
 			g_free (out);
 			g_free (tmp_buf);
 			tmp_buf = NULL;
@@ -320,19 +321,24 @@ sac_handler_end_selector (CRDocHandler * a_handler,
 	}
 }
 
-
-static void
-sac_handler_property (CRDocHandler * a_handler, GString * a_name,
-		      CRTerm * a_expr)
+void
+sac_handler_property (CRDocHandler *a_handler,
+						CRString *ar_name,
+						CRTerm *a_expr,
+						gboolean a_is_important)
 {
 	gchar *out = NULL;
 	guchar* val;	
 	guchar *name ;
 	CssedCssParserData* data;
+	GString * a_name;
 
+	g_return_if_fail (ar_name);	
+	g_return_if_fail (a_expr);
 	g_return_if_fail (a_handler);
-	data = (CssedCssParserData*) a_handler->app_data;	
 
+	data = (CssedCssParserData*) a_handler->app_data;	
+	a_name = ar_name->stryng;
 
 	if (a_name && a_name->str)
 	{
@@ -341,273 +347,130 @@ sac_handler_property (CRDocHandler * a_handler, GString * a_name,
 		if (name && a_expr)
 		{
 			val = cr_term_to_string (a_expr) ;
-			out=g_strdup_printf("\t%s : %s",name,val);
-			document_write_error_to_program_output ((CssedDoc *) data->
-						doc,
-						out,
-						PRO_COLOR);
-			g_free( out );
-			g_free( val );
+			out=g_strdup_printf(_("\t%s: %s"), name, val);
+			document_write_error_to_program_output ((CssedDoc *) data->doc,	out, PRO_COLOR);
+			g_free(out);
+			g_free(val);
 		}
 		else
 		{
 			if( name ){
-				out=g_strdup_printf("\tempty property -> %s",name);
-				document_write_error_to_program_output ((CssedDoc *) data->
-							doc,
-							out,
-							ERR_COLOR);
+				out=g_strdup_printf(_("\tempty property -> %s"),name);
+				document_write_error_to_program_output ((CssedDoc *) data->doc, out, ERR_COLOR);
 				g_free( out );
 				
 			}
 			if( a_expr ){
-				val=g_strdup_printf("\tempty value -> %s",name);
-				document_write_error_to_program_output ((CssedDoc *) data->
-							doc,
-							val,
-							ERR_COLOR);
+				val=g_strdup_printf(_("\tempty value -> %s"),name);
+				document_write_error_to_program_output ((CssedDoc *) data->doc, val, ERR_COLOR);
 				g_free( val );				
 			}
 		}
 
 		if (name)
-		{
 			g_free (name);
-			name = NULL;
-		}
 	}
 }
 
-
-static void
-sac_handler_start_font_face (CRDocHandler * a_handler)
-{
-	g_return_if_fail (a_handler);
-
-}
-
-
-static void
-sac_handler_end_font_face (CRDocHandler * a_handler)
-{
-	g_return_if_fail (a_handler);
-}
-
-static void
-sac_handler_start_media (CRDocHandler * a_handler, GList * a_media_list)
+void
+sac_handler_start_font_face (CRDocHandler * a_handler, CRParsingLocation *a_location)
 {
 	CssedCssParserData* data;
-
 	g_return_if_fail (a_handler);
-	data = (CssedCssParserData*) a_handler->app_data	;
 
-
-	if (a_media_list)
-	{
-		GList *cur = NULL;
-		guchar *medium = NULL;
-		gchar *out = NULL; 
-
-		for (cur = a_media_list; cur; cur = cur->next)
-		{
-			if (cur->data == NULL)
-				continue;
-
-			medium = g_strndup (((GString *) cur->data)->str,
-					    ((GString *) cur->data)->len);
-
-			if (medium == NULL)
-				continue;
-
-			out=g_strdup_printf("Media %s",medium);
-			document_write_error_to_program_output ((CssedDoc *) data->
-							doc,
-							out,
-							MED_COLOR);
-			g_free( out );	
-
-			if (medium)
-			{
-				g_free (medium);
-				medium = NULL;
-			}
-		}
-	}
+	data = (CssedCssParserData*) a_handler->app_data;	
+	document_write_error_to_program_output ((CssedDoc *)
+						data->doc, _("Start font face"),
+						OUT_COLOR);
 }
 
 
-static void
+void
+sac_handler_end_font_face (CRDocHandler * a_handler)
+{
+	CssedCssParserData* data;
+	g_return_if_fail (a_handler);
+
+	data = (CssedCssParserData*) a_handler->app_data;	
+	document_write_error_to_program_output ((CssedDoc *)
+						data->doc, _("End font face"),
+						OUT_COLOR);
+}
+
+void
+sac_handler_start_media (CRDocHandler * a_handler, GList * a_media_list, CRParsingLocation *a_location)
+{
+	CssedCssParserData* data;
+	gchar *out;
+
+	g_return_if_fail (a_handler);
+	g_return_if_fail (a_location);
+
+	data = (CssedCssParserData*) a_handler->app_data	;
+
+	out = g_strdup_printf (_("<span color='black'>%s</span>:<span color='dark green'>%d</span>:\nMedia"), 
+															data->filename, 
+															a_location->line);
+	document_write_error_to_program_output ((CssedDoc *) data->doc, out, MED_COLOR);
+	g_free(out);
+}
+
+
+void
 sac_handler_end_media (CRDocHandler * a_handler, GList * a_media_list)
 {
 	CssedCssParserData* data;
-	gchar* out;
 
 	g_return_if_fail (a_handler);
-	data = (CssedCssParserData*) a_handler->app_data	;
+	data = (CssedCssParserData*) a_handler->app_data;
 
-	if (a_media_list)
-	{
-		GList *cur = NULL;
-		guchar *medium = NULL;
+	document_write_error_to_program_output ((CssedDoc *) data->doc,
+											_("End Media"), MED_COLOR);
 
-		for (cur = a_media_list; cur; cur = cur->next)
-		{
-			if (cur->data == NULL)
-				continue;
-
-			medium = g_strndup (((GString *) cur->data)->str,
-					    ((GString *) cur->data)->len);
-
-			if (medium == NULL)
-				continue;
-			out = g_strdup_printf("end Media %s",medium );
-			document_write_error_to_program_output ((CssedDoc *) data->
-							doc,
-							out,
-							MED_COLOR);
-			g_free( out );	
-
-			if (medium)
-			{
-				g_free (medium);
-				medium = NULL;
-			}
-		}
-	}
 }
 
-static void
-sac_handler_start_page (CRDocHandler * a_handler, GString * a_name,
-			GString * a_pseudo_page)
+void
+sac_handler_start_page (CRDocHandler *a_handler,
+						CRString *ar_name, 
+						CRString *ar_pseudo_page,
+						CRParsingLocation *a_location) 
+
 {
-	guchar *name = NULL, *pseudo_page = NULL;
 	CssedCssParserData* data;
-	gchar* out;
+	gchar *out;
 
 	g_return_if_fail (a_handler);
-	data = (CssedCssParserData*) a_handler->app_data	;
-
-	if (a_name && a_name->str)
-	{
-		name = g_strndup (a_name->str, a_name->len);
-	}
-
-	if (a_pseudo_page && a_pseudo_page->str)
-	{
-		pseudo_page = g_strndup (a_pseudo_page->str,
-					 a_pseudo_page->len);
-	}
-
-	if (name && pseudo_page)
-	{
-			out = g_strdup_printf("Paged Media <span color='navy'>%s : %s</span>",name, pseudo_page);
-			document_write_error_to_program_output ((CssedDoc *) data->
-							doc,
-							out,
-							MED_COLOR);
-			g_free( out );	
-	}else{
-		if (name)
-		{
-			out = g_strdup_printf("Paged Media <span color='navy'>%s</span>",name);
-			document_write_error_to_program_output ((CssedDoc *) data->
-							doc,
-							out,
-							MED_COLOR);
-			g_free( out );	
-		}
-		if (pseudo_page)
-		{
-			out = g_strdup_printf("Paged Media <span color='navy'>%s </span>", pseudo_page);
-			document_write_error_to_program_output ((CssedDoc *) data->doc,	out, MED_COLOR);
-			g_free( out );	
-		}
-	}
-	if (name)
-	{
-		g_free (name);
-		name = NULL;
-	}
-
-	if (pseudo_page)
-	{
-		g_free (pseudo_page);
-		pseudo_page = NULL;
-	}
+	data = (CssedCssParserData*) a_handler->app_data;
+	out = g_strdup_printf (_("<span color='black'>%s</span>:<span color='dark green'>%d</span>:\nPage"), 
+															data->filename, 
+															a_location->line);
+	document_write_error_to_program_output ((CssedDoc*) data->doc, out, MED_COLOR);	
+	g_free(out);
 }
 
-static void
-sac_handler_end_page (CRDocHandler * a_handler, GString * a_name,
-		      GString * a_pseudo_page)
+void
+sac_handler_end_page (CRDocHandler *a_handler,
+					  CRString *ar_name,
+					  CRString *ar_pseudo_page)
 {
-
-	guchar *name = NULL, *pseudo_page = NULL;
 	CssedCssParserData* data;
-	gchar* out;
 
 	g_return_if_fail (a_handler);
-	data = (CssedCssParserData*) a_handler->app_data	;
-
-	if (a_name && a_name->str)
-	{
-		name = g_strndup (a_name->str, a_name->len);
-	}
-
-	if (a_pseudo_page && a_pseudo_page->str)
-	{
-		pseudo_page = g_strndup (a_pseudo_page->str,
-					 a_pseudo_page->len);
-	}
-
-	if (name && pseudo_page)
-	{
-			out = g_strdup_printf("end Paged Media <span color='navy'>%s : %s</span>",name, pseudo_page);
-			document_write_error_to_program_output ((CssedDoc *) data->
-							doc,
-							out,
-							MED_COLOR);
-			g_free( out );	
-	}else{
-		if (name)
-		{
-			out = g_strdup_printf("end Paged Media <span color='navy'>%s</span>",name);
-			document_write_error_to_program_output ((CssedDoc *) data->
-							doc,
-							out,
-							MED_COLOR);
-			g_free( out );	
-		}
-		if (pseudo_page)
-		{
-			out = g_strdup_printf("end Paged Media <span color='navy'>%s </span>", pseudo_page);
-			document_write_error_to_program_output ((CssedDoc *) data->
-							doc,
-							out,
-							MED_COLOR);
-			g_free( out );	
-		}
-	}
-
-	if (name)
-	{
-		g_free (name);
-		name = NULL;
-	}
-
-	if (pseudo_page)
-	{
-		g_free (pseudo_page);
-		pseudo_page = NULL;
-	}
+	data = (CssedCssParserData*) a_handler->app_data;
+	document_write_error_to_program_output ((CssedDoc*) data->doc, _("End Page"), MED_COLOR);
 }
 
 
-static void
-sac_handler_ignorable_at_rule (CRDocHandler * a_handler, GString * a_name)
+void
+sac_handler_ignorable_at_rule (CRDocHandler * a_handler,  CRString *ar_name)
 {
 	guchar *name = NULL;
+	GString * a_name;
 
 	g_return_if_fail (a_handler);
+	g_return_if_fail (ar_name);
+
+	a_name = ar_name->stryng;
 
 	fprintf (stdout, "*********************\n");
 	fprintf (stdout, "ignorable_at_rule\n");
@@ -620,6 +483,7 @@ sac_handler_ignorable_at_rule (CRDocHandler * a_handler, GString * a_name)
 	if (name)
 	{
 		fprintf (stdout, "%s\n", name);
+		g_free(name);
 	}
 
 	fprintf (stdout, "*********************\n\n");
@@ -633,11 +497,8 @@ sac_handler_parse_error (CRDocHandler * a_handler, gint line)
 	
 	data = (CssedCssParserData*) a_handler->app_data	;
 	data->err_count++;	
-	err = g_strdup_printf("[%d] : syntax error (%d)",line+1,data->err_count);
-	document_write_error_to_program_output ((CssedDoc *) data->
-						doc,
-						err,
-						ERR_COLOR);
+	err = g_strdup_printf(_("%s:%d: syntax error (%d)"), data->filename, line+1, data->err_count);
+	document_write_error_to_program_output ((CssedDoc *) data->doc, err, ERR_COLOR);
 	g_free(err);
 }
 
@@ -647,13 +508,10 @@ sac_handler_fatal_error (CRDocHandler * a_handler)
 	CssedCssParserData* data;
 	data = (CssedCssParserData*) a_handler->app_data	;
 
-	document_write_error_to_program_output ((CssedDoc *) data->
-						doc,
-						"FATAL error",
-						ERR_COLOR);
+	document_write_error_to_program_output ((CssedDoc *) data->doc,	_("FATAL error"), ERR_COLOR);
 }
 
-static void
+void
 init_sac_handler (CRDocHandler * a_handler)
 {
 	a_handler->start_document = sac_handler_start_document;
@@ -708,30 +566,54 @@ cssed_cr_parser_parse_buffer (CssedDoc * doc, gchar * buffer, gint len, gboolean
 	CRDocHandler *handler = { 0 };
 	CRParser *parser = NULL;
 	CssedCssParserData* data;
-	gchar* err_buf;
 	gchar* val_buf;
+	gchar *filename;
 	GList* err_list;
 	CRParserError* cr_err;
-	
+	CssedCodePage codepage;
+
 	data = g_malloc(sizeof(CssedCssParserData));	
 	data->doc = doc;
 	data->err_count = 0;
+	data->current_selector = NULL;
+	data->in_media = FALSE;
+	
+	filename = document_get_filename(doc);
+	if( !filename )
+		filename = g_strdup(_("Untitled"));
+	data->filename = filename;
+	
+	codepage = document_get_codepage(doc);
 
-	//g_return_val_if_fail (buffer, CR_BAD_PARAM_ERROR);
-
-	parser = cr_parser_new_from_buf (buffer, len, CR_UTF_8, FALSE);
-	handler = cr_doc_handler_new ();
-	if( dump ){
-		init_sac_handler (handler);
-	}else{
-		init_no_dump_sac_handler (handler);
+	switch( codepage ){
+		case CSSED_CODEPAGE_DEFAULT:
+				parser = cr_parser_new_from_buf (buffer, len, CR_ISO_8859_1, FALSE);
+			break;
+		case CSSED_CODEPAGE_UTF8:
+			parser = cr_parser_new_from_buf (buffer, len, CR_UTF_8, FALSE);
+			break;
+		case CSSED_CODEPAGE_DBCS:
+			parser = cr_parser_new_from_buf (buffer, len, CR_UCS_4, FALSE);	
+			break;		
+		default:
+			parser = cr_parser_new_from_buf (buffer, len, CR_AUTO, FALSE);
 	}
+
+	handler = cr_doc_handler_new ();
+
+	if( dump )
+		init_sac_handler (handler);
+	else
+		init_no_dump_sac_handler (handler);
+	
 	handler->app_data = data;
 	status = cr_parser_set_sac_handler (parser, handler);
 
 	if (status != CR_OK)
 	{//FIXME say somethig to user
 		cr_parser_destroy (parser);
+		g_free(data);
+		g_free(filename);
 		return;
 	}
 
@@ -740,51 +622,48 @@ cssed_cr_parser_parse_buffer (CssedDoc * doc, gchar * buffer, gint len, gboolean
 	switch( status ){		
 		case CR_OK:
 			if( data->err_count > 0 ){
-				err_buf = g_strdup_printf(
-						_("The CSS document can be parsed, but has syntax errors (%d).\nCheck the program output window."),
-						data->err_count);
-				cssed_error_message(err_buf,_("Validation result ok with errors"));
-				g_free(err_buf);
+				cssed_error_message(_("Validation result ok with errors"), 
+									_("The CSS document can be parsed, but has syntax errors (%d).\nCheck the program output window."),	
+									data->err_count);
 			}else{
-				cssed_error_message(
-					_("The CSS document is well formed and\ncan be parsed by a browser."),
-					_("Validation result ok")
-					);
+				cssed_error_message(_("Validation result ok"),
+									_("The CSS document is well formed and\ncan be parsed by a browser."));
 			}
 			break;
 		case  CR_ERROR:	
-			cssed_error_message(_("The CSS document is not well formed"),
-								_("Validation fails"));
+			cssed_error_message(_("Validation fails"), _("The CSS document is not well formed"));
 			break;	
 		case  CR_BAD_PARAM_ERROR:
 		case  CR_INSTANCIATION_FAILED_ERROR:
 		case  CR_EMPTY_PARSER_INPUT_ERROR:
 		case  CR_ENCODING_ERROR:
 		case  CR_ENCODING_NOT_FOUND_ERROR:
-			cssed_error_message(_("The validator found an internal error\nand is unable to continue."),
-								_("Validation fails"));
+			cssed_error_message(_("Validation fails"),
+								_("The validator found an internal error\nand is unable to continue."));
 			break;
 		default:
-			cssed_error_message(_("The CSS document is not well formed"),
-								_("Validation fails"));
+			cssed_error_message(_("Validation fails"),
+								_("The CSS document is not well formed"));
 			break;
 	}
 	
-	 err_list = cr_parser_get_error_stack(parser);
+	err_list = cr_parser_get_error_stack(parser);
 
     for ( ;err_list;err_list = err_list->next )
-    {		
+    {
 		cr_err = (CRParserError*) err_list->data;
 		if ( cr_err != NULL ){
-			val_buf = g_strdup_printf("[%d] - %s ",((int) cr_err->line + 1) ,cr_err->msg	);
+			val_buf = g_strdup_printf("%s:%d: %s ", filename, ((int) cr_err->line + 1) ,cr_err->msg	);
 			document_write_error_to_program_output(doc,val_buf,ERR_COLOR);
 			g_free(val_buf);
 		}
-	}	
+	}
+
+	if( err_list ) g_list_free( err_list );
 	cr_parser_destroy (parser);
-	if( data->current_selector )
-		g_free(data->current_selector);
+
+	if( data->current_selector ) g_free(data->current_selector);
 	g_free(data);
-	handler = NULL;
+	g_free(filename);
 }
 
