@@ -1,4 +1,4 @@
-/*  cssed (c) Iago Rubio, 2003-2004 - A tiny CSS editor.
+/*  cssed (c) Iago Rubio, 2003-2005 - A tiny CSS editor.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,13 +16,13 @@
  */
 
 
-/* some debugging macros */
-#if !defined(DEBUG)
-extern void do_nothing(char *s, ...); // defined in main.c
-#endif
-
-#ifdef DEBUG
-# define DBGMSG g_message
+#ifdef DEBUG_OUTPUT
+# define DBGMSG cssed_message
 #else
 # define DBGMSG do_nothing
 #endif
+
+void
+cssed_message(char* file, gint line, char* message, ...);
+void 
+do_nothing(char* file, gint line, char* message, ...);
