@@ -1,4 +1,4 @@
-/*  cssed (c) Iago Rubio, 2003-2004 - A tiny CSS editor.
+/*  cssed (c) Iago Rubio, 2003-2005 - A tiny CSS editor.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,10 +16,6 @@
  */
 
 GtkWidget* create_window (CssedWindow* window);
-//GtkWidget* create_fileselection (void); unused teemplate
-GtkWidget* create_open_fileselection (CssedWindow* window);
-GtkWidget* create_save_fileselection (CssedWindow* window);
-GtkWidget* create_save_as_fileselection (CssedWindow* window);
 GtkWidget* create_error_dialog (void);
 GtkWidget* create_about (void);
 GtkWidget* create_search_dialog (CssedWindow* window);
