@@ -1,4 +1,4 @@
-/*  cssed (c) Iago Rubio, 2003-2004 - A tiny CSS editor.
+/*  cssed (c) Iago Rubio, 2003-2005 - A tiny CSS editor.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,10 +27,6 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
-#ifdef WITH_TERMINAL
- #include <vte/vte.h>
-#endif
-
 #include "cssedwindow.h"
 #include "callbacks.h"
 #include "interface.h"
@@ -46,8 +42,7 @@
 void on_button_switch_page_clicked (GtkButton * button, gpointer user_data);
 void on_button_selector_add_clicked (GtkButton * button, gpointer user_data);
 void on_button_selector_del_clicked (GtkButton * button, gpointer user_data);
-void on_button_selector_clean_clicked (GtkButton * button,
-				       gpointer user_data);
+void on_button_selector_clean_clicked (GtkButton * button, gpointer user_data);
 void on_button_child_add_clicked (GtkButton * button, gpointer user_data);
 void on_button_child_del_clicked (GtkButton * button, gpointer user_data);
 void on_button_child_clear_clicked (GtkButton * button, gpointer user_data);
@@ -58,12 +53,9 @@ void on_button_class_clean_clicked (GtkButton * button, gpointer user_data);
 void on_button_sibling_add_clicked (GtkButton * button, gpointer user_data);
 void on_button_sibling_del_clicked (GtkButton * button, gpointer user_data);
 void on_button_sibling_clean_clicked (GtkButton * button, gpointer user_data);
-void on_button_contextual_add_clicked (GtkButton * button,
-				       gpointer user_data);
-void on_button_contextual_del_clicked (GtkButton * button,
-				       gpointer user_data);
-void on_button_contextual_clean_clicked (GtkButton * button,
-					 gpointer user_data);
+void on_button_contextual_add_clicked (GtkButton * button, gpointer user_data);
+void on_button_contextual_del_clicked (GtkButton * button, gpointer user_data);
+void on_button_contextual_clean_clicked (GtkButton * button, gpointer user_data);
 
 /* generic function used by callbacks */
 void
@@ -217,7 +209,7 @@ create_selector_wizard ()
 	GtkTreeIter iter;
 	gint i;
 	const gchar *selectors[] = {
-		"a", "a:hover", "a:visited", "a:active", "a:link", "address", "blockquote",
+		"a", "a:link", "a:active", "a:visited", "a:hover", "address", "blockquote",
 		"body", "br", "button", "caption", "cite", "code", "col", "colgroup",
 		"dd","dfn","div","dl","dt","em","fieldset","form","h1","h2","h3","h4","h5","h6",
 		"hr","i","img","input","kbd","label","legend","li","link","ol","optgroup",
@@ -292,8 +284,7 @@ create_selector_wizard ()
 //
 	for (i = 0; selectors[i]; i++)
 	{
-		gtk_list_store_append (GTK_LIST_STORE (selector_store),
-				       &iter);
+		gtk_list_store_append (GTK_LIST_STORE (selector_store), &iter);
 		gtk_list_store_set (GTK_LIST_STORE (selector_store), &iter, 0,
 				    selectors[i], -1);
 	}
@@ -444,6 +435,7 @@ create_selector_wizard ()
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview_selector),
 				 GTK_TREE_MODEL (selector_store));
+	g_object_unref(selector_store);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview_selector),
 					   TRUE);
 //
@@ -495,6 +487,7 @@ create_selector_wizard ()
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview_selector_selected),
 				 GTK_TREE_MODEL (selector_selected_store));
+	g_object_unref(selector_selected_store);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW
 					   (treeview_selector_selected),
 					   TRUE);
@@ -621,6 +614,7 @@ create_selector_wizard ()
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview_child_selected),
 				 GTK_TREE_MODEL (child_selected_store));
+	g_object_unref(child_selected_store);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW
 					   (treeview_child_selected), TRUE);
 //
@@ -735,6 +729,7 @@ create_selector_wizard ()
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview_class_selected),
 				 GTK_TREE_MODEL (class_selected_store));
+	g_object_unref(class_selected_store);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW
 					   (treeview_class_selected), TRUE);
 //
